@@ -97,16 +97,41 @@ class ObjectsController(BaseController):
 
     def get_object_by_id(self,
                          id,
-                         include_tenants=None):
+                         only_protected_objects=None,
+                         storage_domain_id=None,
+                         environments=None,
+                         tenant_ids=None,
+                         include_tenants=None,
+                         include_last_run_info=None,
+                         only_auto_protected_objects=None,
+                         only_leaf_objects=None):
         """Does a GET request to /data-protect/objects/{id}.
 
         Get an object by object id.
 
         Args:
             id (long|int): Specifies the id of Object.
+            only_protected_objects (bool, optional):  If true, the response
+                will include only objects which have been protected.
+            storage_domain_id (long|int, optional): Filter by Storage Domain
+                id. Only Objects protected to this Storage Domain will be
+                returned.
+            environments (Environment2Enum, optional): Filter by environment
+                types such as 'kVMware', 'kView', etc.
+                Only Protected objects protecting the specified environment
+                types are returned.
+            tenant_ids (list of string, optional):  TenantIds contains ids of
+                the tenants for which objects are to be returned.
             include_tenants (bool, optional): If true, the response will
                 include Objects which belongs to all tenants which the current
                 user has permission to see.
+            include_last_run_info (bool, optional): If true, the response will
+                include information about the last protection run on this
+                object.
+            only_auto_protected_objects (bool, None): If true, the response
+                will include only the auto protected objects.
+            only_leaf_objects (bool, None): If true, the response will include
+                only the leaf level objects.
 
         Returns:
             ObjectInformation: Response from the API. Success
@@ -134,7 +159,14 @@ class ObjectsController(BaseController):
             _query_builder = self.config.get_base_uri()
             _query_builder += _url_path
             _query_parameters = {
-                'includeTenants': include_tenants
+                'onlyProtectedObjects': only_protected_objects,
+                'storageDomainId': storage_domain_id,
+                'environments': environments,
+                'tenantIds': tenant_ids,
+                'includeTenants': include_tenants,
+                'includeLastRunInfo': include_last_run_info,
+                'onlyAutoProtectedObjects': only_auto_protected_objects,
+                'onlyLeafObjects': only_leaf_objects
             }
             _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
                 _query_parameters, ConfigurationV2.array_serialization)
