@@ -1157,3 +1157,72 @@ class ProtectionGroupsController(BaseController):
         except Exception as e:
             self.logger.error(e, exc_info = True)
             raise
+
+
+    def get_runs_report(self, id, run_id, object_id, file_type=None):
+        """Does a GET request to /data-protect/protection-groups/{id}/runs/{runId}/objects/{objectId}/downloadFiles.
+
+        Get an CSV report for given objectId and run id. Report will depend
+        on the query parameter fileType, default will be: success_files_list
+        where each row contains the name of file backedup successfully.
+
+        Args:
+            id (string): Specifies a unique id of the Protection Group.
+            run_id (string): Specifies a unique run id of the Protection
+                Group run.
+            object_id (String): Specifies the id of the object for which
+                errors/warnings are to be returned.
+            file_type (string): Specifies the downloaded type, i.e:
+                success_files_list, default: success_files_list
+
+        Returns:
+            void: Response from the API. OK
+
+        Raises:
+            APIException: When an error occurs while fetching the data from
+                the remote API. This exception includes the HTTP Response
+                code, an error message, and the HTTP body that was received in
+                the request.
+
+        """
+        try:
+            self.logger.info('get_runs_report called.')
+    
+            # Validate required parameters
+            self.logger.info('Validating required parameters for get_runs_report.')
+            self.validate_parameters(id=id, run_id=run_id, job_id=job_id)
+    
+            # Prepare query URL
+            self.logger.info('Preparing query URL for get_runs_report.')
+            _url_path = '/data-protect/protection-groups/{id}/runs/{runId}/objects/{objectId}/downloadFiles'
+            _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
+                'id': id,
+                'runId': run_id,
+                'objectId': object_id                
+            })
+            _query_builder = self.config.get_base_uri()
+            _query_builder += _url_path
+            _query_parameters = {
+                'fileType': file_type
+            }
+            _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
+                _query_parameters, ConfigurationV2.array_serialization)
+            _query_url = APIHelper.clean_url(_query_builder)
+    
+            # Prepare and execute request
+            self.logger.info('Preparing and executing request for get_protection_runs.')
+            _request = self.http_client.get(_query_url, headers=_headers)
+
+            CustomHeaderAuth.apply(_request, self.config)
+            _context = self.execute_request(_request, name = 'get_protection_runs')
+
+            # Endpoint and global error handling using HTTP status codes.
+            self.logger.info('Validating response for get_runs_report.')
+            if _context.response.status_code == 0:
+                raise ErrorException('Error', _context)
+            self.validate_response(_context)
+
+        except Exception as e:
+            self.logger.error(e, exc_info = True)
+            raise
+
