@@ -50,7 +50,7 @@ class ProtectionSourcesController(BaseController):
         """
         try:
             self.logger.info('get_protection_sources called.')
-    
+
             # Prepare query URL
             self.logger.info('Preparing query URL for get_protection_sources.')
             _url_path = '/data-protect/sources'
@@ -61,15 +61,15 @@ class ProtectionSourcesController(BaseController):
                 'includeTenants': include_tenants
             }
             _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
-                _query_parameters, ConfigurationV2.array_serialization)
+                                                                        _query_parameters, ConfigurationV2.array_serialization)
             _query_url = APIHelper.clean_url(_query_builder)
-    
+
             # Prepare headers
             self.logger.info('Preparing headers for get_protection_sources.')
             _headers = {
                 'accept': 'application/json'
             }
-    
+
             # Prepare and execute request
             self.logger.info('Preparing and executing request for get_protection_sources.')
             _request = self.http_client.get(_query_url, headers=_headers)
@@ -81,7 +81,7 @@ class ProtectionSourcesController(BaseController):
             if _context.response.status_code == 0:
                 raise ErrorException('Error', _context)
             self.validate_response(_context)
-    
+
             # Return appropriate type
             return APIHelper.json_deserialize(_context.response.raw_body, Sources.from_dictionary)
 
@@ -115,11 +115,11 @@ class ProtectionSourcesController(BaseController):
         """
         try:
             self.logger.info('get_source_attribute_filters called.')
-    
+
             # Validate required parameters
             self.logger.info('Validating required parameters for get_source_attribute_filters.')
             self.validate_parameters(source_uuid=source_uuid)
-    
+
             # Prepare query URL
             self.logger.info('Preparing query URL for get_source_attribute_filters.')
             _url_path = '/data-protect/sources/filters'
@@ -130,15 +130,15 @@ class ProtectionSourcesController(BaseController):
                 'environment': environment
             }
             _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
-                _query_parameters, ConfigurationV2.array_serialization)
+                                                                        _query_parameters, ConfigurationV2.array_serialization)
             _query_url = APIHelper.clean_url(_query_builder)
-    
+
             # Prepare headers
             self.logger.info('Preparing headers for get_source_attribute_filters.')
             _headers = {
                 'accept': 'application/json'
             }
-    
+
             # Prepare and execute request
             self.logger.info('Preparing and executing request for get_source_attribute_filters.')
             _request = self.http_client.get(_query_url, headers=_headers)
@@ -150,7 +150,7 @@ class ProtectionSourcesController(BaseController):
             if _context.response.status_code == 0:
                 raise ErrorException('Error', _context)
             self.validate_response(_context)
-    
+
             # Return appropriate type
             return APIHelper.json_deserialize(_context.response.raw_body, SourceAttributeFiltersResponseParams.from_dictionary)
 
@@ -185,7 +185,7 @@ class ProtectionSourcesController(BaseController):
         """
         try:
             self.logger.info('get_source_registrations called.')
-    
+
             # Prepare query URL
             self.logger.info('Preparing query URL for get_source_registrations.')
             _url_path = '/data-protect/sources/registrations'
@@ -196,15 +196,15 @@ class ProtectionSourcesController(BaseController):
                 'includeTenants': include_tenants
             }
             _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
-                _query_parameters, ConfigurationV2.array_serialization)
+                                                                        _query_parameters, ConfigurationV2.array_serialization)
             _query_url = APIHelper.clean_url(_query_builder)
-    
+
             # Prepare headers
             self.logger.info('Preparing headers for get_source_registrations.')
             _headers = {
                 'accept': 'application/json'
             }
-    
+
             # Prepare and execute request
             self.logger.info('Preparing and executing request for get_source_registrations.')
             _request = self.http_client.get(_query_url, headers=_headers)
@@ -216,7 +216,7 @@ class ProtectionSourcesController(BaseController):
             if _context.response.status_code == 0:
                 raise ErrorException('Error', _context)
             self.validate_response(_context)
-    
+
             # Return appropriate type
             return APIHelper.json_deserialize(_context.response.raw_body, SourceRegistrations.from_dictionary)
 
@@ -246,25 +246,25 @@ class ProtectionSourcesController(BaseController):
         """
         try:
             self.logger.info('register_protection_source called.')
-    
+
             # Validate required parameters
             self.logger.info('Validating required parameters for register_protection_source.')
             self.validate_parameters(body=body)
-    
+
             # Prepare query URL
             self.logger.info('Preparing query URL for register_protection_source.')
             _url_path = '/data-protect/sources/registrations'
             _query_builder = self.config.get_base_uri()
             _query_builder += _url_path
             _query_url = APIHelper.clean_url(_query_builder)
-    
+
             # Prepare headers
             self.logger.info('Preparing headers for register_protection_source.')
             _headers = {
                 'accept': 'application/json',
                 'content-type': 'application/json; charset=utf-8'
             }
-    
+
             # Prepare and execute request
             self.logger.info('Preparing and executing request for register_protection_source.')
             _request = self.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(body))
@@ -276,7 +276,7 @@ class ProtectionSourcesController(BaseController):
             if _context.response.status_code == 0:
                 raise ErrorException('Error', _context)
             self.validate_response(_context)
-    
+
             # Return appropriate type
             return APIHelper.json_deserialize(_context.response.raw_body, SourceRegistration.from_dictionary)
 
@@ -306,27 +306,27 @@ class ProtectionSourcesController(BaseController):
         """
         try:
             self.logger.info('get_protection_source_registration called.')
-    
+
             # Validate required parameters
             self.logger.info('Validating required parameters for get_protection_source_registration.')
             self.validate_parameters(id=id)
-    
+
             # Prepare query URL
             self.logger.info('Preparing query URL for get_protection_source_registration.')
             _url_path = '/data-protect/sources/registrations/{id}'
-            _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
+            _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
                 'id': id
             })
             _query_builder = self.config.get_base_uri()
             _query_builder += _url_path
             _query_url = APIHelper.clean_url(_query_builder)
-    
+
             # Prepare headers
             self.logger.info('Preparing headers for get_protection_source_registration.')
             _headers = {
                 'accept': 'application/json'
             }
-    
+
             # Prepare and execute request
             self.logger.info('Preparing and executing request for get_protection_source_registration.')
             _request = self.http_client.get(_query_url, headers=_headers)
@@ -338,7 +338,7 @@ class ProtectionSourcesController(BaseController):
             if _context.response.status_code == 0:
                 raise ErrorException('Error', _context)
             self.validate_response(_context)
-    
+
             # Return appropriate type
             return APIHelper.json_deserialize(_context.response.raw_body, SourceRegistration.from_dictionary)
 
@@ -371,29 +371,29 @@ class ProtectionSourcesController(BaseController):
         """
         try:
             self.logger.info('update_protection_source_registration called.')
-    
+
             # Validate required parameters
             self.logger.info('Validating required parameters for update_protection_source_registration.')
             self.validate_parameters(id=id,
                                      body=body)
-    
+
             # Prepare query URL
             self.logger.info('Preparing query URL for update_protection_source_registration.')
             _url_path = '/data-protect/sources/registrations/{id}'
-            _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
+            _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
                 'id': id
             })
             _query_builder = self.config.get_base_uri()
             _query_builder += _url_path
             _query_url = APIHelper.clean_url(_query_builder)
-    
+
             # Prepare headers
             self.logger.info('Preparing headers for update_protection_source_registration.')
             _headers = {
                 'accept': 'application/json',
                 'content-type': 'application/json; charset=utf-8'
             }
-    
+
             # Prepare and execute request
             self.logger.info('Preparing and executing request for update_protection_source_registration.')
             _request = self.http_client.put(_query_url, headers=_headers, parameters=APIHelper.json_serialize(body))
@@ -405,7 +405,7 @@ class ProtectionSourcesController(BaseController):
             if _context.response.status_code == 0:
                 raise ErrorException('Error', _context)
             self.validate_response(_context)
-    
+
             # Return appropriate type
             return APIHelper.json_deserialize(_context.response.raw_body, SourceRegistration.from_dictionary)
 
@@ -413,6 +413,81 @@ class ProtectionSourcesController(BaseController):
             self.logger.error(e, exc_info = True)
             raise
 
+    def patch_protection_source_registration(self,
+                                             id,
+                                             body):
+        """Does a PATCH request to /data-protect/sources/registrations/{id}.
+
+        Patches a Protection Source.(Available only for Cassandra).
+
+        Args:
+            id (long|int): Specifies the id of the Protection Source
+                registration.
+            body (SourceRegistrationPatchParameters): Specifies the
+                parameters to patch the registration.
+
+        Returns:
+            SourceRegistration: Response from the API. Success
+
+        Raises:
+            APIException: When an error occurs while fetching the data from
+                the remote API. This exception includes the HTTP Response
+                code, an error message, and the HTTP body that was received in
+                the request.
+
+        """
+        try:
+            self.logger.info('patch_protection_source_registration called.')
+
+            # Validate required parameters
+            self.logger.info('Validating required parameters for '
+                             'patch_protection_source_registration.')
+            self.validate_parameters(id=id,
+                                     body=body)
+
+            # Prepare query URL
+            self.logger.info('Preparing query URL for '
+                             'patch_protection_source_registration.')
+            _url_path = '/data-protect/sources/registrations/{id}'
+            _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
+                'id': id
+            })
+            _query_builder = self.config.get_base_uri()
+            _query_builder += _url_path
+            _query_url = APIHelper.clean_url(_query_builder)
+
+            # Prepare headers
+            self.logger.info('Preparing headers for '
+                             'patch_protection_source_registration.')
+            _headers = {
+                'accept': 'application/json',
+                'content-type': 'application/json; charset=utf-8'
+            }
+
+            # Prepare and execute request
+            self.logger.info('Preparing and executing request for '
+                             'patch_protection_source_registration.')
+            _request = self.http_client.patch(_query_url, headers=_headers,
+                                              parameters=APIHelper.json_serialize(body))
+            CustomHeaderAuth.apply(_request, self.config)
+            _context = self.execute_request(_request, name ='patch_protection_source_registration')
+
+            # Endpoint and global error handling using HTTP status codes.
+            self.logger.info('Validating response for '
+                             'patch_protection_source_registration.')
+            if _context.response.status_code == 0:
+                raise ErrorException('Error', _context)
+            self.validate_response(_context)
+
+            # Return appropriate type
+            return APIHelper.json_deserialize(_context.response.raw_body, SourceRegistration.from_dictionary)
+
+        except Exception as e:
+            self.logger.error(e, exc_info = True)
+            raise
+
+
+
     def delete_protection_source_registration(self,
                                               id):
         """Does a DELETE request to /data-protect/sources/registrations/{id}.
@@ -435,21 +510,21 @@ class ProtectionSourcesController(BaseController):
         """
         try:
             self.logger.info('delete_protection_source_registration called.')
-    
+
             # Validate required parameters
             self.logger.info('Validating required parameters for delete_protection_source_registration.')
             self.validate_parameters(id=id)
-    
+
             # Prepare query URL
             self.logger.info('Preparing query URL for delete_protection_source_registration.')
             _url_path = '/data-protect/sources/registrations/{id}'
-            _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
+            _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
                 'id': id
             })
             _query_builder = self.config.get_base_uri()
             _query_builder += _url_path
             _query_url = APIHelper.clean_url(_query_builder)
-    
+
             # Prepare and execute request
             self.logger.info('Preparing and executing request for delete_protection_source_registration.')
             _request = self.http_client.delete(_query_url)
@@ -488,25 +563,25 @@ class ProtectionSourcesController(BaseController):
         """
         try:
             self.logger.info('test_connection_protection_source called.')
-    
+
             # Validate required parameters
             self.logger.info('Validating required parameters for test_connection_protection_source.')
             self.validate_parameters(body=body)
-    
+
             # Prepare query URL
             self.logger.info('Preparing query URL for test_connection_protection_source.')
             _url_path = '/data-protect/sources/test-connection'
             _query_builder = self.config.get_base_uri()
             _query_builder += _url_path
             _query_url = APIHelper.clean_url(_query_builder)
-    
+
             # Prepare headers
             self.logger.info('Preparing headers for test_connection_protection_source.')
             _headers = {
                 'accept': 'application/json',
                 'content-type': 'application/json; charset=utf-8'
             }
-    
+
             # Prepare and execute request
             self.logger.info('Preparing and executing request for test_connection_protection_source.')
             _request = self.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(body))
@@ -518,7 +593,7 @@ class ProtectionSourcesController(BaseController):
             if _context.response.status_code == 0:
                 raise ErrorException('Error', _context)
             self.validate_response(_context)
-    
+
             # Return appropriate type
             return APIHelper.json_deserialize(_context.response.raw_body, TestConnectionResponseParameters.from_dictionary)
 
@@ -547,27 +622,27 @@ class ProtectionSourcesController(BaseController):
         """
         try:
             self.logger.info('get_catalogs_for_vdc called.')
-    
+
             # Validate required parameters
             self.logger.info('Validating required parameters for get_catalogs_for_vdc.')
             self.validate_parameters(id=id)
-    
+
             # Prepare query URL
             self.logger.info('Preparing query URL for get_catalogs_for_vdc.')
             _url_path = '/data-protect/sources/virtual-datacenter/{id}/catalogs'
-            _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
+            _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
                 'id': id
             })
             _query_builder = self.config.get_base_uri()
             _query_builder += _url_path
             _query_url = APIHelper.clean_url(_query_builder)
-    
+
             # Prepare headers
             self.logger.info('Preparing headers for get_catalogs_for_vdc.')
             _headers = {
                 'accept': 'application/json'
             }
-    
+
             # Prepare and execute request
             self.logger.info('Preparing and executing request for get_catalogs_for_vdc.')
             _request = self.http_client.get(_query_url, headers=_headers)
@@ -579,7 +654,7 @@ class ProtectionSourcesController(BaseController):
             if _context.response.status_code == 0:
                 raise ErrorException('Error', _context)
             self.validate_response(_context)
-    
+
             # Return appropriate type
             return APIHelper.json_deserialize(_context.response.raw_body, VDCCatalogs.from_dictionary)
 
@@ -608,27 +683,27 @@ class ProtectionSourcesController(BaseController):
         """
         try:
             self.logger.info('protection_source_by_id called.')
-    
+
             # Validate required parameters
             self.logger.info('Validating required parameters for protection_source_by_id.')
             self.validate_parameters(id=id)
-    
+
             # Prepare query URL
             self.logger.info('Preparing query URL for protection_source_by_id.')
             _url_path = '/data-protect/sources/{id}'
-            _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
+            _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
                 'id': id
             })
             _query_builder = self.config.get_base_uri()
             _query_builder += _url_path
             _query_url = APIHelper.clean_url(_query_builder)
-    
+
             # Prepare headers
             self.logger.info('Preparing headers for protection_source_by_id.')
             _headers = {
                 'accept': 'application/json'
             }
-    
+
             # Prepare and execute request
             self.logger.info('Preparing and executing request for protection_source_by_id.')
             _request = self.http_client.get(_query_url, headers=_headers)
@@ -640,7 +715,7 @@ class ProtectionSourcesController(BaseController):
             if _context.response.status_code == 0:
                 raise ErrorException('Error', _context)
             self.validate_response(_context)
-    
+
             # Return appropriate type
             return APIHelper.json_deserialize(_context.response.raw_body, ProtectionSource.from_dictionary)
 
