@@ -368,7 +368,8 @@ class RecoveriesController(BaseController):
     def download_files_from_recovery(self,
                                      id,
                                      start_offset=None,
-                                     length=None):
+                                     length=None,
+                                     file_type=None):
         """Does a GET request to /data-protect/recoveries/{id}/downloadFiles.
 
         Download files from the given download file recovery.
@@ -379,6 +380,8 @@ class RecoveriesController(BaseController):
                 file chunk to be downloaded.
             length (long|int, optional): Specifies the length of bytes to
                 download. This can not be greater than 8MB (8388608 byets)
+            file_type (string, optional): Specifies the downloaded type,
+                i.e: error, success_files_list
 
         Returns:
             void: Response from the API. No Content
@@ -407,7 +410,8 @@ class RecoveriesController(BaseController):
             _query_builder += _url_path
             _query_parameters = {
                 'startOffset': start_offset,
-                'length': length
+                'length': length,
+                'fileType': file_type
             }
             _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
                 _query_parameters, ConfigurationV2.array_serialization)
@@ -555,3 +559,58 @@ class RecoveriesController(BaseController):
         except Exception as e:
             self.logger.error(e, exc_info = True)
             raise
+
+
+    def get_recovery_errors_report(self, id):
+        """Does a GET request to /data-protect/recoveries/{id}/download-messages:.
+
+        Get a CSV error report for given recovery operation. Each row in
+        CSV report contains the File Path, error/warning code and error/warning
+        message.
+
+        Args:
+            id (string): Specifies a unique ID of a Recovery.
+
+        Returns:
+            void: Response from the API. No Content
+
+        Raises:
+            APIException: When an error occurs while fetching the data from
+                the remote API. This exception includes the HTTP Response
+                code, an error message, and the HTTP body that was received in
+                the request.
+
+        """
+        try:
+            self.logger.info('get_recovery_errors_report called.')
+    
+            # Validate required parameters
+            self.logger.info('Validating required parameters for get_recovery_errors_report.')
+            self.validate_parameters(id=id)
+    
+            # Prepare query URL
+            self.logger.info('Preparing query URL for get_recovery_errors_report.')
+            _url_path = '/data-protect/recoveries/{id}/download-messages:'
+            _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
+                'id': id
+            })
+            _query_builder = self.config.get_base_uri()
+            _query_builder += _url_path
+            _query_url = APIHelper.clean_url(_query_builder)
+    
+            # Prepare and execute request
+            self.logger.info('Preparing and executing request for get_recovery_errors_report.')
+            _request = self.http_client.get(_query_url)
+            CustomHeaderAuth.apply(_request, self.config)
+            _context = self.execute_request(_request, name = 'get_recovery_errors_report')
+
+            # Endpoint and global error handling using HTTP status codes.
+            self.logger.info('Validating response for get_recovery_errors_report.')
+            if _context.response.status_code == 0:
+                raise ErrorException('Error', _context)
+            self.validate_response(_context)
+
+        except Exception as e:
+            self.logger.error(e, exc_info = True)
+            raise
+
