@@ -325,6 +325,7 @@ class ViewsController(BaseController):
                   max_view_id=None,
                   include_inactive=None,
                   protection_group_ids=None,
+                  view_protection_group_ids=None,
                   view_count_only=None,
                   sort_by_logical_usage=None,
                   internal_access_sids=None,
@@ -380,7 +381,13 @@ class ViewsController(BaseController):
                 replication) should also be returned. Inactive Views are not
                 counted towards the maxCount. By default, this field is set to
                 false.
-            protection_group_ids (list of long|int, optional): Filter by
+            protection_group_ids (list of long|int, optional): This field will
+                be deprecated. Filter by Protection Group ids.
+                Return Views that are being protected by listed Groups, which
+                are specified by ids.
+                If both protectionGroupIds and viewProtectionGroupIds are
+                specified, only viewProtectionGroupIds will be used.
+            view_protection_group_ids (list of string, optional): Filter by
                 Protection Group ids. Return Views that are being protected by
                 listed Groups, which are specified by ids.
             view_count_only (bool, optional): Whether to get just the total
@@ -437,7 +444,7 @@ class ViewsController(BaseController):
                 'viewNames': view_names,
                 'viewIds': view_ids,
                 'storageDomainIds': storage_domain_ids,
-                'storagefilePath': storage_domain_names,
+                'storageDomainNames': storage_domain_names,
                 'protocolAccesses': protocol_accesses,
                 'matchPartialNames': match_partial_names,
                 'maxCount': max_count,
@@ -446,6 +453,7 @@ class ViewsController(BaseController):
                 'maxViewId': max_view_id,
                 'includeInactive': include_inactive,
                 'protectionGroupIds': protection_group_ids,
+                'viewProtectionGroupIds': view_protection_group_ids,
                 'viewCountOnly': view_count_only,
                 'sortByLogicalUsage': sort_by_logical_usage,
                 'internalAccessSids': internal_access_sids,
