@@ -1,4 +1,4 @@
 __all__ = [
     'auth_manager',
-    'custom_header_auth',
+    'custom_header_auth'
 ]
