@@ -396,6 +396,7 @@ __all__ = [
     'disk_format_enum',
     'disk_partition',
     'disk_unit',
+    'distribution_enum',
     'dns_delegation_zone',
     'doc_error',
     'document_type_enum',
@@ -418,6 +419,7 @@ __all__ = [
     'encryption_configuration',
     'encryption_policy_enum',
     'encryption_policy_vault_enum',
+    'entity',
     'entity_identifier',
     'entity_permission_information',
     'entity_proto',
@@ -427,6 +429,7 @@ __all__ = [
     'entity_schema_proto_key_value_descriptor',
     'entity_schema_proto_time_series_descriptor',
     'entity_schema_proto_time_series_descriptor_metric_unit',
+    'entity_services_to_connector_ids_map_entry',
     'entity_type_enum',
     'entity_type_get_file_distribution_stats_enum',
     'env_backup_params',
@@ -486,6 +489,7 @@ __all__ = [
     'exclude_type_get_protected_objects_summary_enum',
     'expand_cloud_cluster_parameters',
     'expand_physical_cluster_parameters',
+    'expiration_action',
     'extended_retention_policy',
     'extended_retention_policy_proto',
     'external_client_subnets',
@@ -673,6 +677,8 @@ __all__ = [
     'job_policy_proto',
     'job_runs_tile',
     'job_type_enum',
+    'k_8_s_filter_params',
+    'k_8_s_filter_params_label_vec',
     'key_value_pair',
     'keystone_acl_proto',
     'keystone_acl_proto_grantees',
@@ -685,12 +691,16 @@ __all__ = [
     'kms_delete_params',
     'kms_update_request_parameters',
     'kubernetes_credentials',
+    'kubernetes_distribution_enum',
+    'kubernetes_env_params',
     'kubernetes_label_attribute',
+    'kubernetes_params',
     'kubernetes_protection_source',
     'kubernetes_restore_parameters',
     'kubernetes_type_enum',
     'kvm_protection_source',
     'kvm_type_enum',
+    'label_attributes_info',
     'label_selector',
     'label_selector_match_labels_entry',
     'last_protection_run_stats',
@@ -1068,6 +1078,7 @@ __all__ = [
     'pure_storage_array',
     'pure_type_enum',
     'pure_volume',
+    'pvc_data',
     'pvc_info',
     'pvc_info_pvc_spec',
     'pvc_info_pvc_spec_resources',
