@@ -39,6 +39,9 @@ class BackupJobProto(object):
             of this job (if any) have been acknowledged by Icebox.
             NOTE: This field may remain false for some period of time even if
             is_deleted field is set to true for the job.
+        allow_parallel_runs (bool): Denotes whether for this host based backup
+            jobs we allow parallel runs or not. This is only supported by
+            VMware adapter.
         backup_qos_principal (int): The backup QoS principal to use for the
             backup job.
         backup_source_params (list of BackupSourceParams): This contains
@@ -304,6 +307,7 @@ class BackupJobProto(object):
         "abort_in_exclusion_window":'abortInExclusionWindow',
         "alerting_policy":'alertingPolicy',
         "all_archival_snapshots_expired":'allArchivalSnapshotsExpired',
+        "allow_parallel_runs":'allowParallelRuns',
         "backup_qos_principal":'backupQosPrincipal',
         "backup_source_params":'backupSourceParams',
         "continue_on_quiesce_failure":'continueOnQuiesceFailure',
@@ -382,6 +386,7 @@ class BackupJobProto(object):
                  abort_in_exclusion_window=None,
                  alerting_policy=None,
                  all_archival_snapshots_expired=None,
+                 allow_parallel_runs=None,
                  backup_qos_principal=None,
                  backup_source_params=None,
                  continue_on_quiesce_failure=None,
@@ -460,6 +465,7 @@ class BackupJobProto(object):
         self.abort_in_exclusion_window = abort_in_exclusion_window
         self.alerting_policy = alerting_policy
         self.all_archival_snapshots_expired = all_archival_snapshots_expired
+        self.allow_parallel_runs = allow_parallel_runs
         self.backup_qos_principal = backup_qos_principal
         self.backup_source_params = backup_source_params
         self.continue_on_quiesce_failure = continue_on_quiesce_failure
@@ -555,6 +561,7 @@ class BackupJobProto(object):
         abort_in_exclusion_window = dictionary.get('abortInExclusionWindow')
         alerting_policy = cohesity_management_sdk.models.alerting_policy_proto.AlertingPolicyProto.from_dictionary(dictionary.get('alertingPolicy')) if dictionary.get('alertingPolicy') else None
         all_archival_snapshots_expired = dictionary.get('allArchivalSnapshotsExpired')
+        allow_parallel_runs = dictionary.get('allowParallelRuns')
         backup_qos_principal = dictionary.get('backupQosPrincipal')
         backup_source_params = None
         if dictionary.get('backupSourceParams') != None:
@@ -660,6 +667,7 @@ class BackupJobProto(object):
         return cls(abort_in_exclusion_window,
                    alerting_policy,
                    all_archival_snapshots_expired,
+                   allow_parallel_runs,
                    backup_qos_principal,
                    backup_source_params,
                    continue_on_quiesce_failure,
