@@ -15,12 +15,20 @@ class CassandraRecoverJobParams(object):
         cassandra_additional_info (CassandraAdditionalParams): Additional
             parameters required for Cassandra recovery.
             TODO (faizan.khan) : Remove this.
-        cassandra_source_version (string): Cassandra source version
-        graph_handling_enabled (bool): whether special graph handling is
-            enabled.
+        finalise_restore_task_id (long|int): The task id which will be used by
+            the finalise restore job.
+        is_finalise_phase (bool): Whether the call is for the finalise restore phase.
         log_recover_params (CassandraLogRecoverJobParams): Additional params
             for log recovery.
         log_restore_directory (string): Logs will be restored to this location.
+        restart_allowed (bool): Option to restart Cassandra services after
+            point in time recovery.
+        restart_command (string): Option command for restarting Cassandra
+            services
+        restart_immediately (bool): Option to restart Cassandra services
+            immediately after the recovery.
+        restart_time (long|int): Option to restart Cassandra services at the
+            specified time
         selected_data_center_vec (list of string):  The data centers selected
             for recovery.
         staging_directory_vec (list of string): Cassandra staging directory
@@ -33,10 +41,14 @@ class CassandraRecoverJobParams(object):
     # Create a mapping from Model property names to API property names
     _names = {
         "cassandra_additional_info": 'cassandraAdditionalInfo',
-        "cassandra_source_version": 'cassandraSourceVersion',
-        "graph_handling_enabled":'graphHandlingEnabled',
+        "finalise_restore_task_id": 'finaliseRestoreTaskId',
+        "is_finalise_phase":'isFinalisePhase',
         "log_recover_params":'logRecoverParams',
         "log_restore_directory":'logRestoreDirectory',
+        "restart_allowed":'restartAllowed',
+        "restart_command":'restartCommand',
+        "restart_immediately":'restartImmediately',
+        "restart_time":'restartTime',
         "selected_data_center_vec": 'selectedDataCenterVec',
         "staging_directory_vec": 'stagingDirectoryVec',
         "suffix":'suffix'
@@ -44,10 +56,14 @@ class CassandraRecoverJobParams(object):
 
     def __init__(self,
                  cassandra_additional_info=None,
-                 cassandra_source_version=None,
-                 graph_handling_enabled=None,
+                 finalise_restore_task_id=None,
+                 is_finalise_phase=None,
                  log_recover_params=None,
                  log_restore_directory=None,
+                 restart_allowed=None,
+                 restart_command=None,
+                 restart_immediately=None,
+                 restart_time=None,
                  selected_data_center_vec=None,
                  staging_directory_vec=None,
                  suffix=None):
@@ -55,10 +71,14 @@ class CassandraRecoverJobParams(object):
 
         # Initialize members of the class
         self.cassandra_additional_info = cassandra_additional_info
-        self.cassandra_source_version = cassandra_source_version
-        self.graph_handling_enabled = graph_handling_enabled
+        self.finalise_restore_task_id = finalise_restore_task_id
+        self.is_finalise_phase = is_finalise_phase
         self.log_recover_params = log_recover_params
         self.log_restore_directory = log_restore_directory
+        self.restart_allowed = restart_allowed
+        self.restart_command = restart_command
+        self.restart_immediately = restart_immediately
+        self.restart_time = restart_time
         self.selected_data_center_vec = selected_data_center_vec
         self.staging_directory_vec = staging_directory_vec
         self.suffix = suffix
@@ -82,20 +102,28 @@ class CassandraRecoverJobParams(object):
 
         # Extract variables from the dictionary
         cassandra_additional_info = cohesity_management_sdk.models.cassandra_additional_params.CassandraAdditionalParams.from_dictionary(dictionary.get('cassandraAdditionalInfo')) if dictionary.get('cassandraAdditionalInfo') else None
-        cassandra_source_version = dictionary.get('cassandraSourceVersion')
-        graph_handling_enabled = dictionary.get('graphHandlingEnabled')
+        finalise_restore_task_id = dictionary.get('finaliseRestoreTaskId')
+        is_finalise_phase = dictionary.get('isFinalisePhase')
         log_recover_params = cohesity_management_sdk.models.cassandra_log_recover_job_params.CassandraLogRecoverJobParams.from_dictionary(dictionary.get('logRecoverParams')) if dictionary.get('logRecoverParams') else None
         log_restore_directory = dictionary.get('logRestoreDirectory')
+        restart_allowed = dictionary.get('restartAllowed')
+        restart_command = dictionary.get('restartCommand')
+        restart_immediately= dictionary.get('restartImmediately')
+        restart_time = dictionary.get('restartTime')
         selected_data_center_vec = dictionary.get('selectedDataCenterVec')
         staging_directory_vec = dictionary.get('stagingDirectoryVec')
         suffix = dictionary.get('suffix')
 
         # Return an object of this model
         return cls(cassandra_additional_info,
-                   cassandra_source_version,
-                   graph_handling_enabled,
+                   finalise_restore_task_id,
+                   is_finalise_phase,
                    log_recover_params,
                    log_restore_directory,
+                   restart_allowed,
+                   restart_command,
+                   restart_immediately,
+                   restart_time,
                    selected_data_center_vec,
                    staging_directory_vec,
                    suffix)
