@@ -4,6 +4,7 @@
 import cohesity_management_sdk.models.amqp_target_config
 import cohesity_management_sdk.models.subnet
 import cohesity_management_sdk.models.cluster_audit_log_configuration
+import cohesity_management_sdk.models.count_by_tier
 import cohesity_management_sdk.models.eula_config
 import cohesity_management_sdk.models.filer_audit_log_configuration
 import cohesity_management_sdk.models.cluster_hardware_info
@@ -65,6 +66,8 @@ class Cluster(object):
         current_time_msecs (long|int): Specifies the current system time on
             the Cohesity Cluster. This value is specified as a Unix epoch
             Timestamp (in microseconds).
+        disk_count_by_tier (list of CountByTier): Specifies the number of
+            disks on the cluster by Storage Tier.
         dns_server_ips (list of string): Array of IP Addresses of DNS Servers.
             Specifies the IP addresses of the DNS Servers used by the Cohesity
             Cluster.
@@ -209,6 +212,7 @@ class Cluster(object):
         "current_op_scheduled_time_secs":'currentOpScheduledTimeSecs',
         "current_operation":'currentOperation',
         "current_time_msecs":'currentTimeMsecs',
+        "disk_count_by_tier":'diskCountByTier',
         "dns_server_ips":'dnsServerIps',
         "domain_names":'domainNames',
         "enable_active_monitoring":'enableActiveMonitoring',
@@ -277,6 +281,7 @@ class Cluster(object):
                  current_op_scheduled_time_secs=None,
                  current_operation=None,
                  current_time_msecs=None,
+                 disk_count_by_tier=None,
                  dns_server_ips=None,
                  domain_names=None,
                  enable_active_monitoring=None,
@@ -345,6 +350,7 @@ class Cluster(object):
         self.current_op_scheduled_time_secs = current_op_scheduled_time_secs
         self.current_operation = current_operation
         self.current_time_msecs = current_time_msecs
+        self.disk_count_by_tier = disk_count_by_tier
         self.dns_server_ips = dns_server_ips
         self.domain_names = domain_names
         self.enable_active_monitoring = enable_active_monitoring
@@ -430,6 +436,11 @@ class Cluster(object):
         current_op_scheduled_time_secs = dictionary.get('currentOpScheduledTimeSecs')
         current_operation = dictionary.get('currentOperation')
         current_time_msecs = dictionary.get('currentTimeMsecs')
+        disk_count_by_tier = None
+        if dictionary.get('diskCountByTier') != None:
+            disk_count_by_tier = list()
+            for structure in dictionary.get('diskCountByTier'):
+                disk_count_by_tier.append(cohesity_management_sdk.models.count_by_tier.CountByTier.from_dictionary(structure))
         dns_server_ips = dictionary.get('dnsServerIps')
         domain_names = dictionary.get('domainNames')
         enable_active_monitoring = dictionary.get('enableActiveMonitoring')
@@ -505,6 +516,7 @@ class Cluster(object):
                    current_op_scheduled_time_secs,
                    current_operation,
                    current_time_msecs,
+                   disk_count_by_tier,
                    dns_server_ips,
                    domain_names,
                    enable_active_monitoring,
