@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021 Cohesity Inc.
+# Copyright 2022 Cohesity Inc.
 
 class EnvironmentGetRestoreTasksEnum(object):
 
@@ -47,6 +47,7 @@ class EnvironmentGetRestoreTasksEnum(object):
         KHDFS: TODO: type description here.
         KHIVE: TODO: type description here.
         KHBASE: TODO: type description here.
+        KUDA: TODO: type description here.
 
 
     """
@@ -129,4 +130,6 @@ class EnvironmentGetRestoreTasksEnum(object):
 
     KHBASE = 'kHBase'
 
+    KUDA = 'kUDA'
+
 
