@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021 Cohesity Inc.
+# Copyright 2022 Cohesity Inc.
 
 class EnvironmentSearchRestoredFilesEnum(object):
 
@@ -46,6 +46,7 @@ class EnvironmentSearchRestoredFilesEnum(object):
         KHDFS: TODO: type description here.
         KHIVE: TODO: type description here.
         KHBASE: TODO: type description here.
+        KUDA: TODO: type description here.
 
 
     """
@@ -126,4 +127,6 @@ class EnvironmentSearchRestoredFilesEnum(object):
 
     KHBASE = 'kHBase'
 
+    KUDA = 'kUDA'
+
 
