@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021 Cohesity Inc.
+# Copyright 2022 Cohesity Inc.
 
 class EnvironmentSnapshotInfoEnum(object):
 
@@ -53,7 +53,7 @@ class EnvironmentSnapshotInfoEnum(object):
     'kHdfs' indicates Hdfs Protection Source environment.
     'kHive' indicates Hive Protection Source environment.
     'kHBase' indicates HBase Protection Source environment.
-    
+    'kUDA' indicates Universal Data Adapter Protection Source environment.
 
     Attributes:
         KVMWARE: TODO: type description here.
@@ -95,6 +95,7 @@ class EnvironmentSnapshotInfoEnum(object):
         KHDFS: TODO: type description here.
         KHIVE: TODO: type description here.
         KHBASE: TODO: type description here.
+        KUDA: TODO: type description here.
 
 
     """
@@ -177,4 +178,6 @@ class EnvironmentSnapshotInfoEnum(object):
 
     KHBASE = 'kHBase'
 
+    KUDA = 'kUDA'
+
 
