@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021 Cohesity Inc.
+# Copyright 2022 Cohesity Inc.
 
 class EnvironmentVaultProviderStatsByEnvEnum(object):
 
@@ -94,6 +94,7 @@ class EnvironmentVaultProviderStatsByEnvEnum(object):
         KHDFS: TODO: type description here.
         KHIVE: TODO: type description here.
         KHBASE: TODO: type description here.
+        KUDA: TODO: type description here.
 
 
     """
@@ -176,3 +177,5 @@ class EnvironmentVaultProviderStatsByEnvEnum(object):
 
     KHBASE = 'kHBase'
 
+    KUDA = 'kUDA'
+
