@@ -62,6 +62,10 @@ class NasBackupParams(object):
         s3_viewbackupproperties (S3ViewBackupProperties): This message captures
             all the details needed by NAS Backup to create S3 views and also
             details needed by Netapp to access the S3 bucket.
+        shared_view_name (string): Specifies the view name if the view is to be
+            shared across multiple backup jobs. Required for backing up
+            multiple directories of the same share through different protection
+            jobs(for faster backup).
         snapshot_change_enabled (bool): Whether this backup job should utilize
             changelist like API when available for faster incremental
             backups.
@@ -87,6 +91,7 @@ class NasBackupParams(object):
         "mixed_mode_preference":'mixedModePreference',
         "nfs_version_preference":'nfsVersionPreference',
         "s3_viewbackupproperties":'s3Viewbackupproperties',
+        "shared_view_name":'sharedViewName',
         "snapshot_change_enabled":'snapshotChangeEnabled',
         "throttling_params":'throttlingParams',
         "whitelisted_ip_addrs":'whitelistedIpAddrs'
@@ -105,6 +110,7 @@ class NasBackupParams(object):
                  mixed_mode_preference=None,
                  nfs_version_preference=None,
                  s3_viewbackupproperties=None,
+                 shared_view_name=None,
                  snapshot_change_enabled=None,
                  throttling_params=None,
                  whitelisted_ip_addrs=None):
@@ -123,6 +129,7 @@ class NasBackupParams(object):
         self.mixed_mode_preference = mixed_mode_preference
         self.nfs_version_preference = nfs_version_preference
         self.s3_viewbackupproperties = s3_viewbackupproperties
+        self.shared_view_name = shared_view_name
         self.snapshot_change_enabled = snapshot_change_enabled
         self.throttling_params = throttling_params
         self.whitelisted_ip_addrs = whitelisted_ip_addrs
@@ -158,6 +165,7 @@ class NasBackupParams(object):
         mixed_mode_preference = dictionary.get('mixedModePreference')
         nfs_version_preference = dictionary.get('nfsVersionPreference')
         s3_viewbackupproperties = cohesity_management_sdk.models.s3_view_backup_properties.S3ViewBackupProperties.from_dictionary(dictionary.get('s3Viewbackupproperties')) if dictionary.get('s3Viewbackupproperties') else None
+        shared_view_name = dictionary.get('sharedViewName')
         snapshot_change_enabled = dictionary.get('snapshotChangeEnabled')
         throttling_params = cohesity_management_sdk.models.nas_throttling_params.NasThrottlingParams.from_dictionary(dictionary.get('throttlingParams')) if dictionary.get('throttlingParams') else None
         whitelisted_ip_addrs = dictionary.get('whitelistedIpAddrs')
@@ -175,6 +183,7 @@ class NasBackupParams(object):
                    mixed_mode_preference,
                    nfs_version_preference,
                    s3_viewbackupproperties,
+                   shared_view_name,
                    snapshot_change_enabled,
                    throttling_params,
                    whitelisted_ip_addrs)
