@@ -1,6 +1,8 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021 Cohesity Inc.
+# Copyright 2022 Cohesity Inc.
 
+import cohesity_management_sdk.models.bond_slave_info
+import cohesity_management_sdk.models.interface_stats
 
 class NetworkInterface(object):
 
@@ -9,10 +11,14 @@ class NetworkInterface(object):
     Specifies the properties of a network interface.
 
     Attributes:
+        active_bond_slave (string): Current active slave. This is only valid
+            in active-backup mode.
         bond_slave_slot_types (list of string): Specifies the types of the
             slots of any slaves if this interface is a bond.
         bond_slaves (list of string): Specifies the names of any slaves if
             this interface is a bond.
+        bond_slaves_details (list of BondSlaveInfo): Specifies the details
+            of the bond slaves.
         bonding_mode (int): Specifies the bonding mode if this interface is
             a bond.
         gateway (string): Specifies the gateway of the interface.
@@ -36,6 +42,7 @@ class NetworkInterface(object):
         speed (string): Specifies the speed of the Interface.
         static_ip (string): Specifies the static IP of the interface.
         static_ip6 (string): Specifies the static IPv6 of the interface.
+        stats (InterfaceStats): Interface Stats.
         subnet (string): Specifies the subnet mask of the interface.
         subnet6 (string): Specifies the subnet6 mask of the interface.
         mtype (int): Specifies the type of interface.
@@ -45,8 +52,10 @@ class NetworkInterface(object):
 
     # Create a mapping from Model property names to API property names
     _names = {
+        "active_bond_slave":'activeBondSlave',
         "bond_slave_slot_types":'bondSlaveSlotTypes',
         "bond_slaves":'bondSlaves',
+        "bond_slaves_details":'bondSlavesDetails',
         "bonding_mode":'bondingMode',
         "gateway":'gateway',
         "gateway6":'gateway6',
@@ -63,6 +72,7 @@ class NetworkInterface(object):
         "speed":'speed',
         "static_ip":'staticIp',
         "static_ip6":'staticIp6',
+        "stats": 'stats',
         "subnet":'subnet',
         "subnet6":'subnet6',
         "mtype":'type',
@@ -70,8 +80,10 @@ class NetworkInterface(object):
     }
 
     def __init__(self,
+                 active_bond_slave=None,
                  bond_slave_slot_types=None,
                  bond_slaves=None,
+                 bond_slaves_details=None,
                  bonding_mode=None,
                  gateway=None,
                  gateway6=None,
@@ -88,6 +100,7 @@ class NetworkInterface(object):
                  speed=None,
                  static_ip=None,
                  static_ip6=None,
+                 stats=None,
                  subnet=None,
                  subnet6=None,
                  mtype=None,
@@ -95,8 +108,10 @@ class NetworkInterface(object):
         """Constructor for the NetworkInterface class"""
 
         # Initialize members of the class
+        self.active_bond_slave = active_bond_slave
         self.bond_slave_slot_types = bond_slave_slot_types
         self.bond_slaves = bond_slaves
+        self.bond_slaves_details = bond_slaves_details
         self.bonding_mode = bonding_mode
         self.gateway = gateway
         self.gateway6 = gateway6
@@ -113,6 +128,7 @@ class NetworkInterface(object):
         self.speed = speed
         self.static_ip = static_ip
         self.static_ip6 = static_ip6
+        self.stats = stats
         self.subnet = subnet
         self.subnet6 = subnet6
         self.mtype = mtype
@@ -137,8 +153,14 @@ class NetworkInterface(object):
             return None
 
         # Extract variables from the dictionary
+        active_bond_slave = dictionary.get('activeBondSlave')
         bond_slave_slot_types = dictionary.get('bondSlaveSlotTypes')
         bond_slaves = dictionary.get('bondSlaves')
+        bond_slaves_details = None
+        if dictionary.get('bondSlavesDetails') != None:
+            bond_slaves_details = list()
+            for structure in dictionary.get('bondSlavesDetails'):
+                bond_slaves_details.append(cohesity_management_sdk.models.bond_slave_info.BondSlaveInfo.from_dictionary(structure))
         bonding_mode = dictionary.get('bondingMode')
         gateway = dictionary.get('gateway')
         gateway6 = dictionary.get('gateway6')
@@ -155,14 +177,17 @@ class NetworkInterface(object):
         speed = dictionary.get('speed')
         static_ip = dictionary.get('staticIp')
         static_ip6 = dictionary.get('staticIp6')
+        stats = cohesity_management_sdk.models.interface_stats.InterfaceStats.from_dictionary(dictionary.get('stats')) if dictionary.get('stats') else None
         subnet = dictionary.get('subnet')
         subnet6 = dictionary.get('subnet6')
         mtype = dictionary.get('type')
         virtual_ip = dictionary.get('virtualIp')
 
         # Return an object of this model
-        return cls(bond_slave_slot_types,
+        return cls(active_bond_slave,
+                   bond_slave_slot_types,
                    bond_slaves,
+                   bond_slaves_details,
                    bonding_mode,
                    gateway,
                    gateway6,
@@ -179,6 +204,7 @@ class NetworkInterface(object):
                    speed,
                    static_ip,
                    static_ip6,
+                   stats,
                    subnet,
                    subnet6,
                    mtype,
