@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021 Cohesity Inc.
+# Copyright 2022 Cohesity Inc.
 
 import cohesity_management_sdk.models.filtering_policy_proto
 import cohesity_management_sdk.models.group_backup_env_params
@@ -30,6 +30,9 @@ class O365BackupEnvParams(object):
             filters: "/" Deny filters: "/tmp", "*.mp4" Using such a policy
             will include everything under the root directory except the /tmp
             directory and all the mp4 files.
+        group_backup_params (GroupBackupEnvParams): TODO (prann) : add
+            teams_backup_params Group specific backup parameters. Refer
+            'GroupBackupEnvParams' for details.
         onedrive_backup_params (OneDriveBackupEnvParams): Message to capture
             any additonal backup params for OneDrive within the Office365
             environment.
@@ -49,6 +52,7 @@ class O365BackupEnvParams(object):
     # Create a mapping from Model property names to API property names
     _names = {
         "filtering_policy":'filteringPolicy',
+        "group_backup_params":'groupBackupParams',
         "onedrive_backup_params":'onedriveBackupParams',
         "outlook_backup_params":'outlookBackupParams',
         "public_folders_backup_params":'publicFoldersBackupParams',
@@ -57,6 +61,7 @@ class O365BackupEnvParams(object):
 
     def __init__(self,
                  filtering_policy=None,
+                 group_backup_params=None,
                  onedrive_backup_params=None,
                  outlook_backup_params=None,
                  public_folders_backup_params=None,
@@ -65,6 +70,7 @@ class O365BackupEnvParams(object):
 
         # Initialize members of the class
         self.filtering_policy = filtering_policy
+        self.group_backup_params = group_backup_params
         self.onedrive_backup_params = onedrive_backup_params
         self.outlook_backup_params = outlook_backup_params
         self.public_folders_backup_params = public_folders_backup_params
@@ -90,6 +96,7 @@ class O365BackupEnvParams(object):
 
         # Extract variables from the dictionary
         filtering_policy = cohesity_management_sdk.models.filtering_policy_proto.FilteringPolicyProto.from_dictionary(dictionary.get('filteringPolicy')) if dictionary.get('filteringPolicy') else None
+        group_backup_params = cohesity_management_sdk.models.group_backup_env_params.GroupBackupEnvParams.from_dictionary(dictionary.get('groupBackupParams')) if dictionary.get('groupBackupParams') else None
         onedrive_backup_params = cohesity_management_sdk.models.one_drive_backup_env_params.OneDriveBackupEnvParams.from_dictionary(dictionary.get('onedriveBackupParams')) if dictionary.get('onedriveBackupParams') else None
         outlook_backup_params = cohesity_management_sdk.models.outlook_backup_env_params.OutlookBackupEnvParams.from_dictionary(dictionary.get('outlookBackupParams')) if dictionary.get('outlookBackupParams') else None
         public_folders_backup_params = cohesity_management_sdk.models.public_folders_backup_env_params.PublicFoldersBackupEnvParams.from_dictionary(dictionary.get('publicFoldersBackupParams')) if dictionary.get('publicFoldersBackupParams') else None
@@ -97,6 +104,7 @@ class O365BackupEnvParams(object):
 
         # Return an object of this model
         return cls(filtering_policy,
+                   group_backup_params,
                    onedrive_backup_params,
                    outlook_backup_params,
                    public_folders_backup_params,
