@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021 Cohesity Inc.
+# Copyright 2022 Cohesity Inc.
 
 class ObjectClassEnum(object):
 
@@ -10,12 +10,14 @@ class ObjectClassEnum(object):
     'kGroup' specifies a group object class.
     'kComputer' specifies a computer object class.
     'kWellKnownPrincipal' specifies a well known principal.
+    'kServiceAccount' specifies a service account object class.
 
     Attributes:
         KUSER: TODO: type description here.
         KGROUP: TODO: type description here.
         KCOMPUTER: TODO: type description here.
         KWELLKNOWNPRINCIPAL: TODO: type description here.
+        KSERVICEACCOUNT: TODO: type description here.
 
     """
 
@@ -27,3 +29,5 @@ class ObjectClassEnum(object):
 
     KWELLKNOWNPRINCIPAL = 'kWellKnownPrincipal'
 
+    KSERVICEACCOUNT = 'kServiceAccount'
+
