@@ -171,6 +171,11 @@ class RegisterProtectionSourceParameters(object):
             belong to a office365 domain.
         pure_type (PureTypeEnum): Specifies the entity type such as
             'kStorageArray' if the environment is kPure.
+        re_register (bool): ReRegister is applicable to Physical Environment.
+            By default, the agent running on a physical host will fail the
+            registration, if it is already registered with the cluster. By
+            setting this option to true, agent can be re-registered with the
+            current cluster.
         source_side_dedup_enabled (bool): This controls whether to use source
             side dedup on the source or not. This is only applicable to
             sources which support source side dedup (e.g., Linux physical
@@ -243,6 +248,7 @@ class RegisterProtectionSourceParameters(object):
         "physical_type":'physicalType',
         "proxy_host_source_id_list":'proxyHostSourceIdList',
         "pure_type":'pureType',
+        "re_register":'reRegister',
         "source_side_dedup_enabled":'sourceSideDedupEnabled',
         "ssl_verification":'sslVerification',
         "subnets":'subnets',
@@ -292,6 +298,7 @@ class RegisterProtectionSourceParameters(object):
                  physical_type=None,
                  proxy_host_source_id_list=None,
                  pure_type=None,
+                 re_register=None,
                  source_side_dedup_enabled=None,
                  ssl_verification=None,
                  subnets=None,
@@ -341,6 +348,7 @@ class RegisterProtectionSourceParameters(object):
         self.physical_type = physical_type
         self.proxy_host_source_id_list = proxy_host_source_id_list
         self.pure_type = pure_type
+        self.re_register = re_register
         self.source_side_dedup_enabled = source_side_dedup_enabled
         self.ssl_verification = ssl_verification
         self.subnets = subnets
@@ -411,6 +419,7 @@ class RegisterProtectionSourceParameters(object):
         physical_type = dictionary.get('physicalType')
         proxy_host_source_id_list = dictionary.get('proxyHostSourceIdList')
         pure_type = dictionary.get('pureType')
+        re_register = dictionary.get('reRegister')
         source_side_dedup_enabled = dictionary.get('sourceSideDedupEnabled')
         ssl_verification = cohesity_management_sdk.models.ssl_verification.SslVerification.from_dictionary(dictionary.get('sslVerification')) if dictionary.get('sslVerification') else None
         subnets = None
@@ -467,6 +476,7 @@ class RegisterProtectionSourceParameters(object):
                    physical_type,
                    proxy_host_source_id_list,
                    pure_type,
+                   re_register,
                    source_side_dedup_enabled,
                    ssl_verification,
                    subnets,
