@@ -32,6 +32,7 @@ class RestoreFilesPreferences(object):
             stamps.
         restore_to_original_paths (bool): If this is true, then files will be
             restored to original paths.
+        save_success_files (bool): Whether to save success files for FLR.
         skip_estimation (bool): Whether to skip the estimation step.
 
     """
@@ -47,6 +48,7 @@ class RestoreFilesPreferences(object):
         "preserve_attributes":'preserveAttributes',
         "preserve_timestamps":'preserveTimestamps',
         "restore_to_original_paths":'restoreToOriginalPaths',
+        "save_success_files":'saveSuccessFiles',
         "skip_estimation":'skipEstimation'
     }
 
@@ -60,6 +62,7 @@ class RestoreFilesPreferences(object):
                  preserve_attributes=None,
                  preserve_timestamps=None,
                  restore_to_original_paths=None,
+                 save_success_files=None,
                  skip_estimation=None):
         """Constructor for the RestoreFilesPreferences class"""
 
@@ -73,6 +76,7 @@ class RestoreFilesPreferences(object):
         self.preserve_attributes = preserve_attributes
         self.preserve_timestamps = preserve_timestamps
         self.restore_to_original_paths = restore_to_original_paths
+        self.save_success_files = save_success_files
         self.skip_estimation = skip_estimation
 
 
@@ -103,6 +107,7 @@ class RestoreFilesPreferences(object):
         preserve_attributes = dictionary.get('preserveAttributes')
         preserve_timestamps = dictionary.get('preserveTimestamps')
         restore_to_original_paths = dictionary.get('restoreToOriginalPaths')
+        save_success_files = dictionary.get('saveSuccessFiles')
         skip_estimation = dictionary.get('skipEstimation')
 
         # Return an object of this model
@@ -115,6 +120,7 @@ class RestoreFilesPreferences(object):
                    preserve_attributes,
                    preserve_timestamps,
                    restore_to_original_paths,
+                   save_success_files,
                    skip_estimation)
 
 
