@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021 Cohesity Inc.
+# Copyright 2022 Cohesity Inc.
 
 import cohesity_management_sdk.models.acropolis_restore_parameters
 import cohesity_management_sdk.models.application_restore_parameters
@@ -40,8 +40,8 @@ class RestoreTask(object):
             Restore Task that retrieves objects from an archive. This field is
             only populated when objects must be retrieved from an archive
             before being restored. overrideDescription:true
-        can_tear_down (bool): Specifies whether it is possible to tear down
-            the objects created by the recovery.
+        clone_status (CloneStatusEnum): Specifies the latest state of the
+            clone. This is only set when this task is a clone task.
         clone_view_parameters (UpdateViewParam): Specifies the View settings
             used when cloning a View.
         continue_on_error (bool): Specifies if the Restore Task should
@@ -117,14 +117,6 @@ class RestoreTask(object):
         target_view_created (bool): Is true if a new View was created by a
             'kCloneVMs' Restore Task. This field is only set for a 'kCloneVMs'
             Restore Task.
-        tear_down_error_message (string): Specifies the error message about
-            the tear down operation if it fails. 
-        tear_down_status (TearDownStatusEnum): Specifies the status of the
-            tear down operation. This is only set when the
-            field 'CanTearDown' is set to true.
-            'kReadyToSchedule' indicates that the task is waiting to be scheduled.
-            'kAdmitted' indicates that the task has been admitted.
-            'kFinished' indicates that the task is finished with or without error.
         mtype (TypeRestoreTaskEnum): Specifies the type of Restore Task.
             'kRecoverVMs' specifies a Restore Task that recovers VMs.
             'kCloneVMs' specifies a Restore Task that clones VMs. 'kCloneView'
@@ -169,7 +161,7 @@ class RestoreTask(object):
         "application_parameters":'applicationParameters',
         "archive_task_uid":'archiveTaskUid',
         "archive_task_uids":'archiveTaskUids',
-        "can_tear_down":'canTearDown',
+        "clone_status":'cloneStatus',
         "clone_view_parameters":'cloneViewParameters',
         "continue_on_error":'continueOnError',
         "datastore_id":'datastoreId',
@@ -190,8 +182,6 @@ class RestoreTask(object):
         "start_time_usecs":'startTimeUsecs',
         "status":'status',
         "target_view_created":'targetViewCreated',
-        "tear_down_error_message":'tearDownErrorMessage',
-        "tear_down_status":'tearDownStatus',
         "mtype":'type',
         "username":'username',
         "view_box_id":'viewBoxId',
@@ -206,7 +196,7 @@ class RestoreTask(object):
                  application_parameters=None,
                  archive_task_uid=None,
                  archive_task_uids=None,
-                 can_tear_down=None,
+                 clone_status=None,
                  clone_view_parameters=None,
                  continue_on_error=None,
                  datastore_id=None,
@@ -227,8 +217,6 @@ class RestoreTask(object):
                  start_time_usecs=None,
                  status=None,
                  target_view_created=None,
-                 tear_down_error_message=None,
-                 tear_down_status=None,
                  mtype=None,
                  username=None,
                  view_box_id=None,
@@ -242,7 +230,7 @@ class RestoreTask(object):
         self.application_parameters = application_parameters
         self.archive_task_uid = archive_task_uid
         self.archive_task_uids = archive_task_uids
-        self.can_tear_down = can_tear_down
+        self.clone_status = clone_status
         self.clone_view_parameters = clone_view_parameters
         self.continue_on_error = continue_on_error
         self.datastore_id = datastore_id
@@ -264,8 +252,6 @@ class RestoreTask(object):
         self.start_time_usecs = start_time_usecs
         self.status = status
         self.target_view_created = target_view_created
-        self.tear_down_error_message = tear_down_error_message
-        self.tear_down_status = tear_down_status
         self.mtype = mtype
         self.username = username
         self.view_box_id = view_box_id
@@ -301,7 +287,7 @@ class RestoreTask(object):
             archive_task_uids = list()
             for structure in dictionary.get('archiveTaskUids'):
                 archive_task_uids.append(cohesity_management_sdk.models.universal_id.UniversalId.from_dictionary(structure))
-        can_tear_down = dictionary.get('canTearDown')
+        clone_status = dictionary.get('cloneStatus')
         clone_view_parameters = cohesity_management_sdk.models.update_view_param.UpdateViewParam.from_dictionary(dictionary.get('cloneViewParameters')) if dictionary.get('cloneViewParameters') else None
         continue_on_error = dictionary.get('continueOnError')
         datastore_id = dictionary.get('datastoreId')
@@ -330,8 +316,6 @@ class RestoreTask(object):
         start_time_usecs = dictionary.get('startTimeUsecs')
         status = dictionary.get('status')
         target_view_created = dictionary.get('targetViewCreated')
-        tear_down_error_message = dictionary.get('tearDownErrorMessage')
-        tear_down_status = dictionary.get('tearDownStatus')
         mtype = dictionary.get('type')
         username = dictionary.get('username')
         view_box_id = dictionary.get('viewBoxId')
@@ -345,7 +329,7 @@ class RestoreTask(object):
                    application_parameters,
                    archive_task_uid,
                    archive_task_uids,
-                   can_tear_down,
+                   clone_status,
                    clone_view_parameters,
                    continue_on_error,
                    datastore_id,
@@ -366,8 +350,6 @@ class RestoreTask(object):
                    start_time_usecs,
                    status,
                    target_view_created,
-                   tear_down_error_message,
-                   tear_down_status,
                    mtype,
                    username,
                    view_box_id,
