@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Cohesity Inc.
+# Copyright 2022 Cohesity Inc.
 
 import cohesity_management_sdk.models.gflag
 
@@ -35,8 +35,7 @@ class ServiceGflags(object):
             responsible for creation of Clusters and configuration of Nodes
             and networking. 'kNexusProxy' is a service that links the Nexus
             service to other services on the Cluster. 'kStorageProxy' is a
-            service for accessing data on external entities. 'kTricorder' is a
-            diagnostic health testing service for Clusters. 'kRtClient' is a
+            service for accessing data on external entities. 'kRtClient' is a
             reverse tunneling client service. 'kVaultProxy' is a service for
             managing external targets that Clusters can be backed up to.
             'kSmbProxy' is an SMB protocol service. 'kBridgeProxy' is the
@@ -50,6 +49,10 @@ class ServiceGflags(object):
             service for communicating with the Cohesity proxies for
             multitenancy. 'kSmb2Proxy' is a new SMB protocol service. 'kOs'
             can be specified in order to do a full reboot.
+            'kEtlServer' is a service responsible for ETling data for
+            globalsearch.
+            'kIcebox' is service that links Icebox service to other services
+            on cluster.
 
     """
 
