@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021 Cohesity Inc.
+# Copyright 2022 Cohesity Inc.
 
 import cohesity_management_sdk.models.smb_permission
 import cohesity_management_sdk.models.subnet
@@ -16,6 +16,8 @@ class Share(object):
             the possible paths that can be used to mount this Share as a SMB
             share. If Active Directory has multiple account names; each
             machine account has its own path.
+        enable_filer_audit_log (bool): Specifies whether to enable filer audit
+            log on this view alias.
         enable_smb_encryption (bool): Specifies the SMB encryption for the
             View Alias. If set, it enables the SMB encryption for the View
             Alias. Encryption is supported only by SMB 3.x dialects. Dialects
@@ -41,6 +43,8 @@ class Share(object):
             addresses that have permissions to access the View Alias.
             (Overrides the Subnets specified at the global Cohesity Cluster
             level and View level.)
+        super_user_sids (list of string): Specifies a list of user sids who:
+            ave Superuser access to this share.
         tenant_id (string): Specifies the unique id of the tenant.
         view_name (string): Specifies the view name this share belongs to.
 
@@ -49,6 +53,7 @@ class Share(object):
     # Create a mapping from Model property names to API property names
     _names = {
         "all_smb_mount_paths":'allSmbMountPaths',
+        "enable_filer_audit_log":'enableFilerAuditLog',
         "enable_smb_encryption":'enableSmbEncryption',
         "enable_smb_view_discovery":'enableSmbViewDiscovery',
         "enforce_smb_encryption":'enforceSmbEncryption',
@@ -59,12 +64,14 @@ class Share(object):
         "share_permissions":'sharePermissions',
         "smb_mount_path":'smbMountPath',
         "subnet_whitelist":'subnetWhitelist',
+        "super_user_sids":'superUserSids',
         "tenant_id":'tenantId',
         "view_name":'viewName'
     }
 
     def __init__(self,
                  all_smb_mount_paths=None,
+                 enable_filer_audit_log=None,
                  enable_smb_encryption=None,
                  enable_smb_view_discovery=None,
                  enforce_smb_encryption=None,
@@ -75,12 +82,14 @@ class Share(object):
                  share_permissions=None,
                  smb_mount_path=None,
                  subnet_whitelist=None,
+                 super_user_sids=None,
                  tenant_id=None,
                  view_name=None):
         """Constructor for the Share class"""
 
         # Initialize members of the class
         self.all_smb_mount_paths = all_smb_mount_paths
+        self.enable_filer_audit_log = enable_filer_audit_log
         self.enable_smb_encryption = enable_smb_encryption
         self.enable_smb_view_discovery = enable_smb_view_discovery
         self.enforce_smb_encryption = enforce_smb_encryption
@@ -91,6 +100,7 @@ class Share(object):
         self.share_permissions = share_permissions
         self.smb_mount_path = smb_mount_path
         self.subnet_whitelist = subnet_whitelist
+        self.super_user_sids = super_user_sids
         self.tenant_id = tenant_id
         self.view_name = view_name
 
@@ -114,6 +124,7 @@ class Share(object):
 
         # Extract variables from the dictionary
         all_smb_mount_paths = dictionary.get('allSmbMountPaths')
+        enable_filer_audit_log = dictionary.get('enableFilerAuditLog')
         enable_smb_encryption = dictionary.get('enableSmbEncryption')
         enable_smb_view_discovery = dictionary.get('enableSmbViewDiscovery')
         enforce_smb_encryption = dictionary.get('enforceSmbEncryption')
@@ -132,11 +143,13 @@ class Share(object):
             subnet_whitelist = list()
             for structure in dictionary.get('subnetWhitelist'):
                 subnet_whitelist.append(cohesity_management_sdk.models.subnet.Subnet.from_dictionary(structure))
+        super_user_sids = dictionary.get('superUserSids')
         tenant_id = dictionary.get('tenantId')
         view_name = dictionary.get('viewName')
 
         # Return an object of this model
         return cls(all_smb_mount_paths,
+                   enable_filer_audit_log,
                    enable_smb_encryption,
                    enable_smb_view_discovery,
                    enforce_smb_encryption,
@@ -147,6 +160,7 @@ class Share(object):
                    share_permissions,
                    smb_mount_path,
                    subnet_whitelist,
+                   super_user_sids,
                    tenant_id,
                    view_name)
 
