@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Cohesity Inc.
+# Copyright 2022 Cohesity Inc.
 
 class StatusBackupRunEnum(object):
 
@@ -14,6 +14,9 @@ class StatusBackupRunEnum(object):
     'kCanceled' indicates the task has been canceled.
     'kSuccess' indicates the task was successful.
     'kFailure' indicates the task failed.
+    'kWarning' indicates the task has finished with warning.
+    'kOnHold' indicates the task is kept onHold.
+    'kMissed' indicates the task is missed.
 
     Attributes:
         KACCEPTED: TODO: type description here.
@@ -22,9 +25,11 @@ class StatusBackupRunEnum(object):
         KCANCELED: TODO: type description here.
         KSUCCESS: TODO: type description here.
         KFAILURE: TODO: type description here.
+        KWARNING: TODO: type description here.
+        KONHOLD: TODO: type description here.
+        KMISSED: TODO: type description here.
 
     """
-
     KACCEPTED = 'kAccepted'
 
     KRUNNING = 'kRunning'
@@ -37,3 +42,9 @@ class StatusBackupRunEnum(object):
 
     KFAILURE = 'kFailure'
 
+    KWARNING = 'kWarning'
+
+    KONHOLD = 'kOnHold'
+
+    KMISSED = 'kMissed'
+
