@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Cohesity Inc.
+# Copyright 2022 Cohesity Inc.
 
 class TypeRestoreSourceSummaryByObjectTypeElementEnum(object):
 
@@ -29,6 +29,8 @@ class TypeRestoreSourceSummaryByObjectTypeElementEnum(object):
     files and folders in zip format.
     'kRecoverEmails' specifies a Restore Task that recovers the mailbox/email
     items.
+    'kConvertToPst' specifies a PST conversion task for selected mailbox/email
+    items.
     'kRecoverDisks' specifies a Restore Task that recovers the virtual disks.
     'kRecoverNamespaces' specifies a Restore Task that recovers Kubernetes
     namespaces.
@@ -45,6 +47,7 @@ class TypeRestoreSourceSummaryByObjectTypeElementEnum(object):
         KDEPLOYVMS: TODO: type description here.
         KDOWNLOADFILES: TODO: type description here.
         KRECOVEREMAILS: TODO: type description here.
+        KCONVERTTOPST: TODO: type description here.
         KRECOVERDISKS: TODO: type description here.
         KRECOVERNAMESPACES: TODO: type description here.
         KCLONEVMSTOVIEW: TODO: type description here.
@@ -82,6 +85,8 @@ class TypeRestoreSourceSummaryByObjectTypeElementEnum(object):
 
     KRECOVEREMAILS = "kRecoverEmails"
 
+    KCONVERTTOPST = "kConvertToPst"
+
     KRECOVERDISKS = "kRecoverDisks"
 
     KRECOVERNAMESPACES = "kRecoverNamespaces"
