@@ -96,6 +96,11 @@ class UpdateProtectionSourceParameters(object):
             the protection source id of the windows physical host which will
             be used during the protection and recovery of the sites that
             belong to a office365 domain.
+        re_register (bool): ReRegister is applicable to Physical Environment.
+            By default, the agent running on a physical host will fail the
+            registration, if it is already registered with the cluster. By
+            setting this option to true, agent can be re-registered with the
+            current cluster.
         source_side_dedup_enabled (bool): This controls whether to use source
             side dedup on the source or not. This is only applicable to
             sources which support source side dedup (e.g., Linux physical
@@ -150,6 +155,7 @@ class UpdateProtectionSourceParameters(object):
         "office_365_region":'office365Region',
         "password":'password',
         "proxy_host_source_id_list":'proxyHostSourceIdList',
+        "re_register":'reRegister',
         "source_side_dedup_enabled":'sourceSideDedupEnabled',
         "ssl_verification":'sslVerification',
         "subnets":'subnets',
@@ -185,6 +191,7 @@ class UpdateProtectionSourceParameters(object):
                  office_365_region=None,
                  password=None,
                  proxy_host_source_id_list=None,
+                 re_register=None,
                  source_side_dedup_enabled=None,
                  ssl_verification=None,
                  subnets=None,
@@ -220,6 +227,7 @@ class UpdateProtectionSourceParameters(object):
         self.office_365_region = office_365_region
         self.password = password
         self.proxy_host_source_id_list = proxy_host_source_id_list
+        self.re_register = re_register
         self.source_side_dedup_enabled = source_side_dedup_enabled
         self.ssl_verification = ssl_verification
         self.subnets = subnets
@@ -272,6 +280,7 @@ class UpdateProtectionSourceParameters(object):
         office_365_region = dictionary.get('office365Region')
         password = dictionary.get('password')
         proxy_host_source_id_list = dictionary.get('proxyHostSourceIdList')
+        re_register = dictionary.get('reRegister')
         source_side_dedup_enabled = dictionary.get('sourceSideDedupEnabled')
         ssl_verification = cohesity_management_sdk.models.ssl_verification.SslVerification.from_dictionary(dictionary.get('sslVerification')) if dictionary.get('sslVerification') else None
         subnets = None
@@ -314,6 +323,7 @@ class UpdateProtectionSourceParameters(object):
                    office_365_region,
                    password,
                    proxy_host_source_id_list,
+                   re_register,
                    source_side_dedup_enabled,
                    ssl_verification,
                    subnets,
