@@ -1,10 +1,12 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021 Cohesity Inc.
+# Copyright 2022 Cohesity Inc.
 
+import cohesity_management_sdk.models.audit_log_settings
 import cohesity_management_sdk.models.cluster_identifier
 import cohesity_management_sdk.models.google_account_info
 import cohesity_management_sdk.models.idp_user_info
 import cohesity_management_sdk.models.mcm_user_profile
+import cohesity_management_sdk.models.mfa_info
 import cohesity_management_sdk.models.tenant_config
 import cohesity_management_sdk.models.preferences
 import cohesity_management_sdk.models.salesforce_account_info
@@ -18,6 +20,7 @@ class User(object):
     Attributes:
         additional_group_names (list of string): Array of Additional Groups.
             Specifies the names of additional groups this User may belong to.
+        audit_log_settings (AuditLogSettings): Specifies audit settings.
         authentication_type (AuthenticationTypeUserEnum): Specifies the
             authentication type of the user. 'kAuthLocal' implies
             authenticated user is a local user. 'kAuthAd' implies
@@ -31,6 +34,8 @@ class User(object):
         created_time_msecs (long|int): Specifies the epoch time in
             milliseconds when the user account was created on the Cohesity
             Cluster.
+        current_password (string): Specifies the current password when
+            updating the password.
         description (string): Specifies a description about the user.
         domain (string): Specifies the fully qualified domain name (FQDN) of
             an Active Directory or LOCAL for the default LOCAL domain on the
@@ -53,15 +58,35 @@ class User(object):
         idp_user_info (IdpUserInfo): Specifies an IdP User's information
             logged in using an IdP. This information is not stored on the
             Cluster.
+        is_account_locked (bool): Specifies whether the user account is locked.
+        is_active (bool): IsActive specifies whether or not a user is active,
+            or has been disactivated by the customer. The default behavior is
+            'true'.
+        is_cluster_mfa_enabled (bool): Specifies if MFA is enabled on cluster.
+        last_successful_login_time_msecs (long|int): Specifies the epoch time
+            in milliseconds when the user was last logged in successfully.
         last_updated_time_msecs (long|int): Specifies the epoch time in
             milliseconds when the user account was last modified on the
             Cohesity Cluster.
+        lockout_reason (LockoutReasonUserEnum): Specifies the lockout reason
+            of the user if it is locked.
+            'NotLocked' implies the user is not locked.
+            'FailedLoginAttempts' the account is locked due to
+            many failed login attempts.
+            'LockedByAdmin' implies the account is locked by the admin user.
+            'Inactivity' implies the account is locked due to long time of
+            inactivity.
+        mfa_info (MfaInfo): Specifies MFA info if MFA is enabled.
+        mfa_methods (list of string): Specifies MFA methods that enabled on the
+            cluster.
         org_membership (list of TenantConfig): OrgMembership contains the list
             of all available tenantIds for this user to switch to. Only when
             creating the session user, this field is populated on the fly. We
             discover the tenantIds from various groups assigned to the users.
         password (string): Specifies the password of this user.
         preferences (Preferences): TODO: type description here.
+        previous_login_time_msecs (long|int):  Specifies the epoch time in
+            milliseconds of previous user login.
         primary_group_name (string): Specifies the name of the primary group
             of this User.
         privilege_ids (list of PrivilegeIdUserEnum): Array of Privileges.
@@ -69,6 +94,8 @@ class User(object):
             populated based on the union of all privileges in roles. Type for
             unique privilege Id values. All below enum values specify a value
             for all uniquely defined privileges in Cohesity.
+        profiles (list of McmUserProfile): Specifies the user profiles.
+            NOTE: Currently used for Helios.
         restricted (bool): Whether the user is a restricted user. A restricted
             user can only view the objects he has permissions to.
         roles (list of string): Array of Roles.  Specifies the Cohesity roles
@@ -90,9 +117,11 @@ class User(object):
     # Create a mapping from Model property names to API property names
     _names = {
         "additional_group_names":'additionalGroupNames',
+        "audit_log_settings":'auditLogSettings',
         "authentication_type":'authenticationType',
         "cluster_identifiers":'clusterIdentifiers',
         "created_time_msecs":'createdTimeMsecs',
+        "current_password":'currentPassword',
         "description":'description',
         "domain":'domain',
         "effective_time_msecs":'effectiveTimeMsecs',
@@ -102,10 +131,18 @@ class User(object):
         "google_account":'googleAccount',
         "group_roles":'groupRoles',
         "idp_user_info":'idpUserInfo',
+        "is_account_locked":'isAccountLocked',
+        "is_active":'isActive',
+        "is_cluster_mfa_enabled":'isClusterMfaEnabled',
+        "last_successful_login_time_msecs":'lastSuccessfulLoginTimeMsecs',
         "last_updated_time_msecs":'lastUpdatedTimeMsecs',
+        "lockout_reason":'lockoutReason',
+        "mfa_info":'mfaInfo',
+        "mfa_methods":'mfaMethods',
         "org_membership":'orgMembership',
         "password":'password',
         "preferences":'preferences',
+        "previous_login_time_msecs":'previousLoginTimeMsecs',
         "primary_group_name":'primaryGroupName',
         "privilege_ids":'privilegeIds',
         "profiles":'profiles',
@@ -122,9 +159,11 @@ class User(object):
 
     def __init__(self,
                  additional_group_names=None,
+                 audit_log_settings=None,
                  authentication_type=None,
                  cluster_identifiers=None,
                  created_time_msecs=None,
+                 current_password=None,
                  description=None,
                  domain=None,
                  effective_time_msecs=None,
@@ -134,10 +173,18 @@ class User(object):
                  google_account=None,
                  group_roles=None,
                  idp_user_info=None,
+                 is_account_locked=None,
+                 is_active=None,
+                 is_cluster_mfa_enabled=None,
+                 last_successful_login_time_msecs=None,
                  last_updated_time_msecs=None,
+                 lockout_reason=None,
+                 mfa_info=None,
+                 mfa_methods=None,
                  org_membership=None,
                  password=None,
                  preferences=None,
+                 previous_login_time_msecs=None,
                  primary_group_name=None,
                  privilege_ids=None,
                  profiles=None,
@@ -154,9 +201,11 @@ class User(object):
 
         # Initialize members of the class
         self.additional_group_names = additional_group_names
+        self.audit_log_settings = audit_log_settings
         self.authentication_type = authentication_type
         self.cluster_identifiers = cluster_identifiers
         self.created_time_msecs = created_time_msecs
+        self.current_password = current_password
         self.description = description
         self.domain = domain
         self.effective_time_msecs = effective_time_msecs
@@ -166,12 +215,21 @@ class User(object):
         self.google_account = google_account
         self.group_roles = group_roles
         self.idp_user_info = idp_user_info
+        self.is_account_locked = is_account_locked
+        self.is_active = is_active
+        self.is_cluster_mfa_enabled = is_cluster_mfa_enabled
+        self.last_successful_login_time_msecs = last_successful_login_time_msecs
         self.last_updated_time_msecs = last_updated_time_msecs
+        self.lockout_reason = lockout_reason
+        self.mfa_info = mfa_info
+        self.mfa_methods = mfa_methods
         self.org_membership = org_membership
         self.password = password
         self.preferences = preferences
+        self.previous_login_time_msecs = previous_login_time_msecs
         self.primary_group_name = primary_group_name
         self.privilege_ids = privilege_ids
+        self.profiles = profiles
         self.restricted = restricted
         self.roles = roles
         self.s_3_access_key_id = s_3_access_key_id
@@ -202,6 +260,7 @@ class User(object):
 
         # Extract variables from the dictionary
         additional_group_names = dictionary.get('additionalGroupNames')
+        audit_log_settings = cohesity_management_sdk.models.audit_log_settings.AuditLogSettings.from_dictionary(dictionary.get('auditLogSettings')) if dictionary.get('auditLogSettings') else None
         authentication_type = dictionary.get('authenticationType')
         cluster_identifiers = None
         if dictionary.get('clusterIdentifiers') != None:
@@ -209,6 +268,7 @@ class User(object):
             for structure in dictionary.get('clusterIdentifiers'):
                 cluster_identifiers.append(cohesity_management_sdk.models.cluster_identifier.ClusterIdentifier.from_dictionary(structure))
         created_time_msecs = dictionary.get('createdTimeMsecs')
+        current_password = dictionary.get('currentPassword')
         description = dictionary.get('description')
         domain = dictionary.get('domain')
         effective_time_msecs = dictionary.get('effectiveTimeMsecs')
@@ -218,7 +278,14 @@ class User(object):
         google_account = cohesity_management_sdk.models.google_account_info.GoogleAccountInfo.from_dictionary(dictionary.get('googleAccount')) if dictionary.get('googleAccount') else None
         group_roles = dictionary.get('groupRoles')
         idp_user_info = cohesity_management_sdk.models.idp_user_info.IdpUserInfo.from_dictionary(dictionary.get('idpUserInfo')) if dictionary.get('idpUserInfo') else None
+        is_account_locked = dictionary.get('isAccountLocked')
+        is_active = dictionary.get('isActive')
+        is_cluster_mfa_enabled = dictionary.get('isClusterMfaEnabled')
+        last_successful_login_time_msecs = dictionary.get('lastSuccessfulLoginTimeMsecs')
         last_updated_time_msecs = dictionary.get('lastUpdatedTimeMsecs')
+        lockout_reason = dictionary.get('lockoutReason')
+        mfa_info = cohesity_management_sdk.models.mfa_info.MfaInfo.from_dictionary(dictionary.get('mfaInfo')) if dictionary.get('mfaInfo') else None
+        mfa_methods = dictionary.get('mfaMethods')
         org_membership = None
         if dictionary.get('orgMembership') != None:
             org_membership = list()
@@ -226,8 +293,14 @@ class User(object):
                 org_membership.append(cohesity_management_sdk.models.tenant_config.TenantConfig.from_dictionary(structure))
         password = dictionary.get('password')
         preferences = cohesity_management_sdk.models.preferences.Preferences.from_dictionary(dictionary.get('preferences')) if dictionary.get('preferences') else None
+        previous_login_time_msecs = dictionary.get('previousLoginTimeMsecs')
         primary_group_name = dictionary.get('primaryGroupName')
         privilege_ids = dictionary.get('privilegeIds')
+        profiles = None
+        if dictionary.get('profiles') != None:
+            profiles = list()
+            for structure in dictionary.get('profiles'):
+                profiles.append(cohesity_management_sdk.models.mcm_user_profile.McmUserProfile.from_dictionary(structure))
         restricted = dictionary.get('restricted')
         roles = dictionary.get('roles')
         s_3_access_key_id = dictionary.get('s3AccessKeyId')
@@ -240,9 +313,11 @@ class User(object):
 
         # Return an object of this model
         return cls(additional_group_names,
+                   audit_log_settings,
                    authentication_type,
                    cluster_identifiers,
                    created_time_msecs,
+                   current_password,
                    description,
                    domain,
                    effective_time_msecs,
@@ -252,12 +327,21 @@ class User(object):
                    google_account,
                    group_roles,
                    idp_user_info,
+                   is_account_locked,
+                   is_active,
+                   is_cluster_mfa_enabled,
+                   last_successful_login_time_msecs,
                    last_updated_time_msecs,
+                   lockout_reason,
+                   mfa_info,
+                   mfa_methods,
                    org_membership,
                    password,
                    preferences,
+                   previous_login_time_msecs,
                    primary_group_name,
                    privilege_ids,
+                   profiles,
                    restricted,
                    roles,
                    s_3_access_key_id,
