@@ -131,6 +131,7 @@ class View(object):
             setting.
         override_global_whitelist (bool): Specifies whether view level client
             subnet whitelist overrides cluster and global setting.
+        owner_sid (string): Specifies the Sid of the view owner.
         protocol_access (ProtocolAccessEnum): Specifies the supported
             Protocols for the View. 'kAll' enables protocol access to all
             three views: NFS, SMB and S3. 'kNFSOnly' enables protocol access
@@ -221,6 +222,7 @@ class View(object):
         "nfs_root_squash":'nfsRootSquash',
         "override_global_netgroup_whitelist":'overrideGlobalNetgroupWhitelist',
         "override_global_whitelist":'overrideGlobalWhitelist',
+        "owner_sid":'ownerSid',
         "protocol_access":'protocolAccess',
         "qos":'qos',
         "s_3_access_path":'s3AccessPath',
@@ -281,6 +283,7 @@ class View(object):
                  nfs_root_squash=None,
                  override_global_netgroup_whitelist=None,
                  override_global_whitelist=None,
+                 owner_sid=None,
                  protocol_access=None,
                  qos=None,
                  s_3_access_path=None,
@@ -341,6 +344,7 @@ class View(object):
         self.nfs_root_squash = nfs_root_squash
         self.override_global_netgroup_whitelist = override_global_netgroup_whitelist
         self.override_global_whitelist = override_global_whitelist
+        self.owner_sid = owner_sid
         self.protocol_access = protocol_access
         self.qos = qos
         self.s_3_access_path = s_3_access_path
@@ -426,6 +430,7 @@ class View(object):
         nfs_root_squash = cohesity_management_sdk.models.nfs_squash.NfsSquash.from_dictionary(dictionary.get('nfsRootSquash')) if dictionary.get('nfsRootSquash') else None
         override_global_netgroup_whitelist = dictionary.get('overrideGlobalNetgroupWhitelist')
         override_global_whitelist = dictionary.get('overrideGlobalWhitelist')
+        owner_sid = dictionary.get('ownerSid')
         protocol_access = dictionary.get('protocolAccess')
         qos = cohesity_management_sdk.models.qo_s.QoS.from_dictionary(dictionary.get('qos')) if dictionary.get('qos') else None
         s_3_access_path = dictionary.get('s3AccessPath')
@@ -493,6 +498,7 @@ class View(object):
                    nfs_root_squash,
                    override_global_netgroup_whitelist,
                    override_global_whitelist,
+                   owner_sid,
                    protocol_access,
                    qos,
                    s_3_access_path,
