@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021 Cohesity Inc.
+# Copyright 2022 Cohesity Inc.
 
 
-class ViewIdMappingProtoProtocolAccessInfo(object):
+class ViewIdMappingProto_ProtocolAccessInfo(object):
 
     """Implementation of the 'ViewIdMappingProto_ProtocolAccessInfo' model.
 
@@ -36,7 +36,7 @@ class ViewIdMappingProtoProtocolAccessInfo(object):
                  s_3_access=None,
                  smb_access=None,
                  swift_access=None):
-        """Constructor for the ViewIdMappingProtoProtocolAccessInfo class"""
+        """Constructor for the ViewIdMappingProto_ProtocolAccessInfo class"""
 
         # Initialize members of the class
         self.iscsi_access = iscsi_access
