@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021 Cohesity Inc.
+# Copyright 2022 Cohesity Inc.
 
 import cohesity_management_sdk.models.cluster_config_proto_subnet
 import cohesity_management_sdk.models.view_id_mapping_proto_protocol_access_info
@@ -18,7 +18,7 @@ class ViewParams(object):
             for the new view.
         disable_nfs_access (bool): Whether to disable NFS access in the new
             view.
-        protocol_access_info (ViewIdMappingProtoProtocolAccessInfo): The
+        protocol_access_info (ViewIdMappingProto_ProtocolAccessInfo): The
             protocol access override (if any) of the view.
         qos_mapping_vec (list of ClusterConfigProtoQoSMapping): The qos
             mappings (if any) for the new view.
@@ -89,7 +89,7 @@ class ViewParams(object):
             for structure in dictionary.get('clientSubnetWhitelistVec'):
                 client_subnet_whitelist_vec.append(cohesity_management_sdk.models.cluster_config_proto_subnet.ClusterConfigProtoSubnet.from_dictionary(structure))
         disable_nfs_access = dictionary.get('disableNfsAccess')
-        protocol_access_info = cohesity_management_sdk.models.view_id_mapping_proto_protocol_access_info.ViewIdMappingProtoProtocolAccessInfo.from_dictionary(dictionary.get('protocolAccessInfo')) if dictionary.get('protocolAccessInfo') else None
+        protocol_access_info = cohesity_management_sdk.models.view_id_mapping_proto_protocol_access_info.ViewIdMappingProto_ProtocolAccessInfo.from_dictionary(dictionary.get('protocolAccessInfo')) if dictionary.get('protocolAccessInfo') else None
         qos_mapping_vec = None
         if dictionary.get('qosMappingVec') != None:
             qos_mapping_vec = list()
