@@ -9,6 +9,7 @@ class AcropolisObjectTypeEnum(object):
     Attributes:
         KPRISMCENTRAL: TODO: type description here.
         KSTANDALONECLUSTER: TODO: type description here.
+        KOTHERHYPERVISORCLUSTER: TODO: type description here.
         KCLUSTER: TODO: type description here.
         KHOST: TODO: type description here.
         KVIRTUALMACHINE: TODO: type description here.
@@ -21,6 +22,8 @@ class AcropolisObjectTypeEnum(object):
 
     KSTANDALONECLUSTER = 'kStandaloneCluster'
 
+    KOTHERHYPERVISORCLUSTER = 'kOtherHypervisorCluster'
+
     KCLUSTER = 'kCluster'
 
     KHOST = 'kHost'
@@ -30,4 +33,3 @@ class AcropolisObjectTypeEnum(object):
     KNETWORK = 'kNetwork'
 
     KSTORAGECONTAINER = 'kStorageContainer'
-
