@@ -10,20 +10,24 @@ class ApplyPatch(object):
     Attributes:
         service (string): Specifies the name of the service whose patch should
             be applied.
+        all (bool): Specifies all the available patches should be applied.
 
     """
 
     # Create a mapping from Model property names to API property names
     _names = {
-        "service":'service'
+        "service":'service',
+        "all":'all'
     }
 
     def __init__(self,
-                 service=None):
+                 service=None,
+                 all=None):
         """Constructor for the ApplyPatch class"""
 
         # Initialize members of the class
         self.service = service
+        self.all = all
 
 
     @classmethod
@@ -45,8 +49,10 @@ class ApplyPatch(object):
 
         # Extract variables from the dictionary
         service = dictionary.get('service')
+        all = dictionary.get('all')
 
         # Return an object of this model
-        return cls(service)
+        return cls(service,
+                   all)
 
 
