@@ -2,7 +2,7 @@
 
 class ArchivalObjectStatusEnum(object):
 
-    """Implementation of the 'archivalObjectStatus' enum.
+    """Implementation of the 'ArchivalObjectStatus' enum.
 
     TODO: type enum description here.
 
@@ -12,6 +12,7 @@ class ArchivalObjectStatusEnum(object):
         KFAILED: TODO: type description here.
         KWAITINGFORNEXTATTEMPT: TODO: type description here.
         KWARNING: TODO: type description here.
+        KWAITINGFOROLDERBACKUPRUN: TODO: type description here.
 
     """
 
@@ -25,3 +26,4 @@ class ArchivalObjectStatusEnum(object):
 
     KWARNING = 'kWarning'
 
+    KWAITINGFOROLDERBACKUPRUN = 'kWaitingForOlderBackupRun'
