@@ -19,6 +19,8 @@ class AzureObjectTypeEnum(object):
         KSUBNET: TODO: type description here.
         KCOMPUTEOPTIONS: TODO: type description here.
         KSNAPSHOTMANAGERPERMIT: TODO: type description here.
+        KTAG: TODO: type description here.
+        KAVAILABILITYSET: TODO: type description here.
 
     """
 
@@ -46,3 +48,6 @@ class AzureObjectTypeEnum(object):
 
     KSNAPSHOTMANAGERPERMIT = 'kSnapshotManagerPermit'
 
+    KTAG = 'kTag'
+
+    KAVAILABILITYSET = 'kAvailabilitySet'
