@@ -112,6 +112,10 @@ class CreateView(object):
             of this view.
         self_service_snapshot_config (SelfServiceSnapshotConfig2): Specifies
             self service config of this view.
+        is_externally_triggered_backup_target (bool): Specifies whether the
+            view is for externally triggered backup target. If so, Magneto
+            will ignore the backup schedule for the view protection job of
+            this view. By default it is disabled.
         enable_nfs_view_discovery (bool): If set, it enables discovery of view
             for NFS.
         nfs_all_squash (NfsAllSquash): Specifies the NFS all squash config.
@@ -191,6 +195,7 @@ class CreateView(object):
         "is_read_only":'isReadOnly',
         "view_pinning_config":'viewPinningConfig',
         "self_service_snapshot_config":'selfServiceSnapshotConfig',
+        "is_externally_triggered_backup_target":'isExternallyTriggeredBackupTarget',
         "enable_nfs_view_discovery":'enableNfsViewDiscovery',
         "nfs_all_squash":'nfsAllSquash',
         "nfs_root_permissions":'nfsRootPermissions',
@@ -244,6 +249,7 @@ class CreateView(object):
                  is_read_only=None,
                  view_pinning_config=None,
                  self_service_snapshot_config=None,
+                 is_externally_triggered_backup_target=None,
                  enable_nfs_view_discovery=None,
                  nfs_all_squash=None,
                  nfs_root_permissions=None,
@@ -297,6 +303,7 @@ class CreateView(object):
         self.is_read_only = is_read_only
         self.view_pinning_config = view_pinning_config
         self.self_service_snapshot_config = self_service_snapshot_config
+        self.is_externally_triggered_backup_target = is_externally_triggered_backup_target
         self.enable_nfs_view_discovery = enable_nfs_view_discovery
         self.nfs_all_squash = nfs_all_squash
         self.nfs_root_permissions = nfs_root_permissions
@@ -375,6 +382,7 @@ class CreateView(object):
         is_read_only = dictionary.get('isReadOnly')
         view_pinning_config = cohesity_management_sdk.models_v2.view_pinning_config_2.ViewPinningConfig2.from_dictionary(dictionary.get('viewPinningConfig')) if dictionary.get('viewPinningConfig') else None
         self_service_snapshot_config = cohesity_management_sdk.models_v2.self_service_snapshot_config_2.SelfServiceSnapshotConfig2.from_dictionary(dictionary.get('selfServiceSnapshotConfig')) if dictionary.get('selfServiceSnapshotConfig') else None
+        is_externally_triggered_backup_target = dictionary.get('isExternallyTriggeredBackupTarget')
         enable_nfs_view_discovery = dictionary.get('enableNfsViewDiscovery')
         nfs_all_squash = cohesity_management_sdk.models_v2.nfs_all_squash.NfsAllSquash.from_dictionary(dictionary.get('nfsAllSquash')) if dictionary.get('nfsAllSquash') else None
         nfs_root_permissions = cohesity_management_sdk.models_v2.nfs_root_permissions_2.NfsRootPermissions2.from_dictionary(dictionary.get('nfsRootPermissions')) if dictionary.get('nfsRootPermissions') else None
@@ -427,6 +435,7 @@ class CreateView(object):
                    is_read_only,
                    view_pinning_config,
                    self_service_snapshot_config,
+                   is_externally_triggered_backup_target,
                    enable_nfs_view_discovery,
                    nfs_all_squash,
                    nfs_root_permissions,
