@@ -16,6 +16,9 @@ import cohesity_management_sdk.models_v2.smb_permission
 import cohesity_management_sdk.models_v2.acl_config_1
 import cohesity_management_sdk.models_v2.owner_info_2
 import cohesity_management_sdk.models_v2.view_share_permissions
+import cohesity_management_sdk.models_v2.view_protection_config
+import cohesity_management_sdk.models_v2.view_pinning_config
+import cohesity_management_sdk.models_v2.self_service_snapshot_config
 
 class CreateViewRequest(object):
 
@@ -91,6 +94,13 @@ class CreateViewRequest(object):
         view_lock_enabled (bool): Specifies whether view lock is enabled. If
             enabled the view cannot be modified or deleted until unlock. By
             default it is disabled.
+        is_read_only (bool): Specifies if the view is a read only view. User
+            will no longer be able to write to this view if this is set to
+            true.
+        view_pinning_config (ViewPinningConfig):  Specifies the pinning
+            config of this view.
+        self_service_snapshot_config (SelfServiceSnapshotConfig): Specifies
+            self service config of this view.
         is_externally_triggered_backup_target (bool): Specifies whether the
             view is for externally triggered backup target. If so, Magneto
             will ignore the backup schedule for the view protection job of
@@ -105,6 +115,14 @@ class CreateViewRequest(object):
         nfs_root_squash
             (NfsSquashSpecifiesTheSquashConfigForClientSubnetWhitelist): TODO:
             type description here.
+        enable_nfs_unix_authentication (bool): If set, it enables NFS UNIX
+            Authentication
+        enable_nfs_kerberos_authentication (bool): If set, it enables NFS
+            Kerberos Authentication
+        enable_nfs_kerberos_integrity (bool): If set, it enables NFS Kerberos
+            Integrity
+        enable_nfs_kerberos_privacy (bool): If set, it enables NFS Kerberos
+            Privacy
         enable_smb_view_discovery (bool): If set, it enables discovery of view
             for SMB.
         enable_smb_access_based_enumeration (bool): Specifies if access-based
@@ -129,6 +147,8 @@ class CreateViewRequest(object):
             information about SMB permissions.
         share_permissions (list of SMBPermission): Specifies a list of share
             level permissions.
+        s3_access_path (string): Specifies the path to access this View as an
+            S3 share.
         acl_config (AclConfig1): Specifies the ACL config of the View as an S3
             bucket.
         owner_info (OwnerInfo2): Specifies the owner info of the View as an S3
@@ -140,6 +160,8 @@ class CreateViewRequest(object):
         case_insensitive_names_enabled (bool): Specifies whether to support
             case insensitive file/folder names. This parameter can only be set
             during create and cannot be changed.
+        view_protection_config (ViewProtectionConfig): Specifies the protection
+            config of the View.
         object_services_mapping_config (ObjectServicesMappingConfigEnum):
             Specifies the Object Services key mapping config of the view. This
             parameter can only be set during create and cannot be changed.
@@ -147,6 +169,12 @@ class CreateViewRequest(object):
             of Object Services key mapping config.
         swift_user_domain (string): Specifies the Keystone user domain.
         swift_username (string): Specifies the Keystone username.
+        versioning (VersioningEnum): Specifies the versioning state of S3
+            bucket. Buckets can be in one of three states: UnVersioned
+            (default), VersioningEnabled, or VersioningSuspended. Once
+            versioning is enabled for a bucket, it can never return to an
+            UnVersioned state. However, versioning on the bucket can be
+            suspended.
 
     """
 
@@ -178,11 +206,18 @@ class CreateViewRequest(object):
         "swift_project_name":'swiftProjectName',
         "access_sids":'accessSids',
         "view_lock_enabled":'viewLockEnabled',
+        "is_read_only":'isReadOnly',
+        "view_pinning_config":'viewPinningConfig',
+        "self_service_snapshot_config":'selfServiceSnapshotConfig',
         "is_externally_triggered_backup_target":'isExternallyTriggeredBackupTarget',
         "enable_nfs_view_discovery":'enableNfsViewDiscovery',
         "nfs_all_squash":'nfsAllSquash',
         "nfs_root_permissions":'nfsRootPermissions',
         "nfs_root_squash":'nfsRootSquash',
+        "enable_nfs_unix_authentication":'enableNfsUnixAuthentication',
+        "enable_nfs_kerberos_authentication":'enableNfsKerberosAuthentication',
+        "enable_nfs_kerberos_integrity":'enableNfsKerberosIntegrity',
+        "enable_nfs_kerberos_privacy":'enableNfsKerberosPrivacy',
         "enable_smb_view_discovery":'enableSmbViewDiscovery',
         "enable_smb_access_based_enumeration":'enableSmbAccessBasedEnumeration',
         "enable_smb_encryption":'enableSmbEncryption',
@@ -191,12 +226,15 @@ class CreateViewRequest(object):
         "enable_smb_oplock":'enableSmbOplock',
         "smb_permissions_info":'smbPermissionsInfo',
         "share_permissions":'sharePermissions',
+        "s3_access_path":'s3AccessPath',
         "acl_config":'aclConfig',
         "owner_info":'ownerInfo',
         "case_insensitive_names_enabled":'caseInsensitiveNamesEnabled',
+        "view_protection_config":'viewProtectionConfig',
         "object_services_mapping_config":'objectServicesMappingConfig',
         "swift_user_domain":'swiftUserDomain',
-        "swift_username":'swiftUsername'
+        "swift_username":'swiftUsername',
+        "versioning":'versioning'
     }
 
     def __init__(self,
@@ -226,11 +264,18 @@ class CreateViewRequest(object):
                  swift_project_name=None,
                  access_sids=None,
                  view_lock_enabled=None,
+                 is_read_only=None,
+                 view_pinning_config=None,
+                 self_service_snapshot_config=None,
                  is_externally_triggered_backup_target=None,
                  enable_nfs_view_discovery=None,
                  nfs_all_squash=None,
                  nfs_root_permissions=None,
                  nfs_root_squash=None,
+                 enable_nfs_unix_authentication=None,
+                 enable_nfs_kerberos_authentication=None,
+                 enable_nfs_kerberos_integrity=None,
+                 enable_nfs_kerberos_privacy=None,
                  enable_smb_view_discovery=None,
                  enable_smb_access_based_enumeration=None,
                  enable_smb_encryption=None,
@@ -239,12 +284,15 @@ class CreateViewRequest(object):
                  enable_smb_oplock=None,
                  smb_permissions_info=None,
                  share_permissions=None,
+                 s3_access_path=None,
                  acl_config=None,
                  owner_info=None,
                  case_insensitive_names_enabled=None,
+                 view_protection_config=None,
                  object_services_mapping_config=None,
                  swift_user_domain=None,
-                 swift_username=None):
+                 swift_username=None,
+                 versioning=None):
         """Constructor for the CreateViewRequest class"""
 
         # Initialize members of the class
@@ -271,11 +319,18 @@ class CreateViewRequest(object):
         self.swift_project_name = swift_project_name
         self.access_sids = access_sids
         self.view_lock_enabled = view_lock_enabled
+        self.is_read_only = is_read_only
+        self.view_pinning_config = view_pinning_config
+        self.self_service_snapshot_config = self_service_snapshot_config
         self.is_externally_triggered_backup_target = is_externally_triggered_backup_target
         self.enable_nfs_view_discovery = enable_nfs_view_discovery
         self.nfs_all_squash = nfs_all_squash
         self.nfs_root_permissions = nfs_root_permissions
         self.nfs_root_squash = nfs_root_squash
+        self.enable_nfs_unix_authentication = enable_nfs_unix_authentication
+        self.enable_nfs_kerberos_authentication = enable_nfs_kerberos_authentication
+        self.enable_nfs_kerberos_integrity = enable_nfs_kerberos_integrity
+        self.enable_nfs_kerberos_privacy = enable_nfs_kerberos_privacy
         self.enable_smb_view_discovery = enable_smb_view_discovery
         self.enable_smb_access_based_enumeration = enable_smb_access_based_enumeration
         self.enable_smb_encryption = enable_smb_encryption
@@ -284,15 +339,18 @@ class CreateViewRequest(object):
         self.enable_smb_oplock = enable_smb_oplock
         self.smb_permissions_info = smb_permissions_info
         self.share_permissions = share_permissions
+        self.s3_access_path = s3_access_path
         self.acl_config = acl_config
         self.owner_info = owner_info
         self.name = name
         self.category = category
         self.storage_domain_id = storage_domain_id
         self.case_insensitive_names_enabled = case_insensitive_names_enabled
+        self.view_protection_config = view_protection_config
         self.object_services_mapping_config = object_services_mapping_config
         self.swift_user_domain = swift_user_domain
         self.swift_username = swift_username
+        self.versioning = versioning
 
 
     @classmethod
@@ -347,11 +405,18 @@ class CreateViewRequest(object):
         swift_project_name = dictionary.get('swiftProjectName')
         access_sids = dictionary.get('accessSids')
         view_lock_enabled = dictionary.get('viewLockEnabled')
+        is_read_only = dictionary.get('isReadOnly')
+        view_pinning_config = cohesity_management_sdk.models_v2.view_pinning_config.ViewPinningConfig.from_dictionary(dictionary.get('viewPinningConfig')) if dictionary.get('viewPinningConfig') else None
+        self_service_snapshot_config = cohesity_management_sdk.models_v2.self_service_snapshot_config.SelfServiceSnapshotConfig.from_dictionary(dictionary.get('selfServiceSnapshotConfig')) if dictionary.get('selfServiceSnapshotConfig') else None
         is_externally_triggered_backup_target = dictionary.get('isExternallyTriggeredBackupTarget')
         enable_nfs_view_discovery = dictionary.get('enableNfsViewDiscovery')
         nfs_all_squash = cohesity_management_sdk.models_v2.nfs_squash_specifies_the_squash_config_for_client_subnet_whitelist.NfsSquashSpecifiesTheSquashConfigForClientSubnetWhitelist.from_dictionary(dictionary.get('nfsAllSquash')) if dictionary.get('nfsAllSquash') else None
         nfs_root_permissions = cohesity_management_sdk.models_v2.nfs_root_permissions.NfsRootPermissions.from_dictionary(dictionary.get('nfsRootPermissions')) if dictionary.get('nfsRootPermissions') else None
         nfs_root_squash = cohesity_management_sdk.models_v2.nfs_squash_specifies_the_squash_config_for_client_subnet_whitelist.NfsSquashSpecifiesTheSquashConfigForClientSubnetWhitelist.from_dictionary(dictionary.get('nfsRootSquash')) if dictionary.get('nfsRootSquash') else None
+        enable_nfs_unix_authentication = dictionary.get('enableNfsUnixAuthentication')
+        enable_nfs_kerberos_authentication = dictionary.get('enableNfsKerberosAuthentication')
+        enable_nfs_kerberos_integrity = dictionary.get('enableNfsKerberosIntegrity')
+        enable_nfs_kerberos_privacy = dictionary.get('enableNfsKerberosPrivacy')
         enable_smb_view_discovery = dictionary.get('enableSmbViewDiscovery')
         enable_smb_access_based_enumeration = dictionary.get('enableSmbAccessBasedEnumeration')
         enable_smb_encryption = dictionary.get('enableSmbEncryption')
@@ -360,12 +425,15 @@ class CreateViewRequest(object):
         enable_smb_oplock = dictionary.get('enableSmbOplock')
         smb_permissions_info = cohesity_management_sdk.models_v2.smb_permissions_information.SMBPermissionsInformation.from_dictionary(dictionary.get('smbPermissionsInfo')) if dictionary.get('smbPermissionsInfo') else None
         share_permissions = cohesity_management_sdk.models_v2.view_share_permissions.ViewSharePermissions.from_dictionary(dictionary.get('sharePermissions')) if dictionary.get('sharePermissions') else None
+        s3_access_path = dictionary.get('s3AccessPath')
         acl_config = cohesity_management_sdk.models_v2.acl_config_1.AclConfig1.from_dictionary(dictionary.get('aclConfig')) if dictionary.get('aclConfig') else None
         owner_info = cohesity_management_sdk.models_v2.owner_info_2.OwnerInfo2.from_dictionary(dictionary.get('ownerInfo')) if dictionary.get('ownerInfo') else None
         case_insensitive_names_enabled = dictionary.get('caseInsensitiveNamesEnabled')
+        view_protection_config = cohesity_management_sdk.models_v2.view_protection_config.ViewProtectionConfig.from_dictionary(dictionary.get('viewProtectionConfig')) if dictionary.get('viewProtectionConfig') else None
         object_services_mapping_config = dictionary.get('objectServicesMappingConfig')
         swift_user_domain = dictionary.get('swiftUserDomain')
         swift_username = dictionary.get('swiftUsername')
+        versioning = dictionary.get('versioning')
 
         # Return an object of this model
         return cls(name,
@@ -394,11 +462,18 @@ class CreateViewRequest(object):
                    swift_project_name,
                    access_sids,
                    view_lock_enabled,
+                   is_read_only,
+                   view_pinning_config,
+                   self_service_snapshot_config,
                    is_externally_triggered_backup_target,
                    enable_nfs_view_discovery,
                    nfs_all_squash,
                    nfs_root_permissions,
                    nfs_root_squash,
+                   enable_nfs_unix_authentication,
+                   enable_nfs_kerberos_authentication,
+                   enable_nfs_kerberos_integrity,
+                   enable_nfs_kerberos_privacy,
                    enable_smb_view_discovery,
                    enable_smb_access_based_enumeration,
                    enable_smb_encryption,
@@ -407,11 +482,14 @@ class CreateViewRequest(object):
                    enable_smb_oplock,
                    smb_permissions_info,
                    share_permissions,
+                   s3_access_path,
                    acl_config,
                    owner_info,
                    case_insensitive_names_enabled,
+                   view_protection_config,
                    object_services_mapping_config,
                    swift_user_domain,
-                   swift_username)
+                   swift_username,
+                   versioning)
 
 
