@@ -11,6 +11,7 @@ class KubernetesObjectTypeEnum(object):
         KNAMESPACE: TODO: type description here.
         KSERVICE: TODO: type description here.
         KPVC: TODO: type description here.
+        KLABEL: TODO: type description here.
 
     """
 
@@ -22,3 +23,4 @@ class KubernetesObjectTypeEnum(object):
 
     KPVC = 'kPVC'
 
+    KLABEL = 'kLabel'
