@@ -20,6 +20,8 @@ class O365ObjectTypeEnum(object):
         KGRAPHUSER: TODO: type description here.
         KPUBLICFOLDERS: TODO: type description here.
         KPUBLICFOLDER: TODO: type description here.
+        KTEAMS: TODO: type description here.
+        KTEAM: TODO: type description here.
 
     """
 
@@ -49,3 +51,7 @@ class O365ObjectTypeEnum(object):
 
     KPUBLICFOLDER = 'kPublicFolder'
 
+    KTEAMS = 'kTeams'
+
+    KTEAM = 'kTeam'
+
