@@ -16,6 +16,7 @@ class ObjectType1Enum(object):
         MONGOOBJECTS: TODO: type description here.
         HDFSOBJECTS: TODO: type description here.
         PUBLICFOLDERS: TODO: type description here.
+        EXCHANGEOBJECTS: TODO: type description here.
 
     """
 
@@ -37,3 +38,4 @@ class ObjectType1Enum(object):
 
     PUBLICFOLDERS = 'PublicFolders'
 
+    EXCHANGEOBJECTS = 'ExchangeObjects'
