@@ -71,6 +71,13 @@ class Recovery(object):
         tear_down_message (string): Specifies the error message about the tear
             down operation if it fails.
         messages (list of string): Specifies messages about the recovery.
+        is_parent_recovery (bool): Specifies whether the current recovery
+            operation has created child recoveries. This is currently used in
+            SQL recovery where multiple child recoveries can be tracked under
+            a common/parent recovery.
+        parent_recovery_id (string): If current recovery is child recovery
+            triggered by another parent recovery operation, then this field
+            will specify the id of the parent recovery.
         vmware_params (RecoverVmwareEnvironmentParams): Specifies the recovery
             options specific to VMware environment.
         aws_params (RecoverAWSEnvironmentParams): Specifies the recovery
@@ -142,6 +149,8 @@ class Recovery(object):
         "tear_down_status":'tearDownStatus',
         "tear_down_message":'tearDownMessage',
         "messages":'messages',
+        "is_parent_recovery":'isParentRecovery',
+        "parent_recovery_id":'parentRecoveryId',
         "vmware_params":'vmwareParams',
         "aws_params":'awsParams',
         "gcp_params":'gcpParams',
@@ -185,6 +194,8 @@ class Recovery(object):
                  tear_down_status=None,
                  tear_down_message=None,
                  messages=None,
+                 is_parent_recovery=None,
+                 parent_recovery_id=None,
                  vmware_params=None,
                  aws_params=None,
                  gcp_params=None,
@@ -228,6 +239,8 @@ class Recovery(object):
         self.tear_down_status = tear_down_status
         self.tear_down_message = tear_down_message
         self.messages = messages
+        self.is_parent_recovery = is_parent_recovery
+        self.parent_recovery_id = parent_recovery_id
         self.vmware_params = vmware_params
         self.aws_params = aws_params
         self.gcp_params = gcp_params
@@ -292,6 +305,8 @@ class Recovery(object):
         tear_down_status = dictionary.get('tearDownStatus')
         tear_down_message = dictionary.get('tearDownMessage')
         messages = dictionary.get('messages')
+        is_parent_recovery = dictionary.get('isParentRecovery')
+        parent_recovery_id = dictionary.get('parentRecoveryId')
         vmware_params = cohesity_management_sdk.models_v2.recover_vmware_environment_params.RecoverVmwareEnvironmentParams.from_dictionary(dictionary.get('vmwareParams')) if dictionary.get('vmwareParams') else None
         aws_params = cohesity_management_sdk.models_v2.recover_aws_environment_params.RecoverAWSEnvironmentParams.from_dictionary(dictionary.get('awsParams')) if dictionary.get('awsParams') else None
         gcp_params = cohesity_management_sdk.models_v2.recover_gcp_environment_params.RecoverGCPEnvironmentParams.from_dictionary(dictionary.get('gcpParams')) if dictionary.get('gcpParams') else None
@@ -334,6 +349,8 @@ class Recovery(object):
                    tear_down_status,
                    tear_down_message,
                    messages,
+                   is_parent_recovery,
+                   parent_recovery_id,
                    vmware_params,
                    aws_params,
                    gcp_params,
