@@ -2,7 +2,7 @@
 
 class ReplicationObjectStatusEnum(object):
 
-    """Implementation of the 'replicationObjectStatus' enum.
+    """Implementation of the 'ReplicationObjectStatus' enum.
 
     TODO: type enum description here.
 
@@ -12,6 +12,7 @@ class ReplicationObjectStatusEnum(object):
         KFAILED: TODO: type description here.
         KWAITINGFORNEXTATTEMPT: TODO: type description here.
         KWARNING: TODO: type description here.
+        KWAITINGFOROLDERBACKUPRUN: TODO: type description here.
 
     """
 
@@ -25,3 +26,4 @@ class ReplicationObjectStatusEnum(object):
 
     KWARNING = 'kWarning'
 
+    KWAITINGFOROLDERBACKUPRUN = 'kWaitingForOlderBackupRun'
