@@ -8,6 +8,7 @@ class Status14Enum(object):
 
     Attributes:
         RUNNING: TODO: type description here.
+        ACCEPTED: TODO: type description here.
         CANCELED: TODO: type description here.
         CANCELING: TODO: type description here.
         FAILED: TODO: type description here.
@@ -18,6 +19,8 @@ class Status14Enum(object):
 
     """
 
+    ACCEPTED = 'Accepted'
+
     RUNNING = 'Running'
 
     CANCELED = 'Canceled'
