@@ -13,6 +13,8 @@ class Status6Enum(object):
     but there were some warning messages.
 
     Attributes:
+
+        ACCEPTED: TODO: type description here.
         RUNNING: TODO: type description here.
         CANCELED: TODO: type description here.
         CANCELING: TODO: type description here.
@@ -24,6 +26,8 @@ class Status6Enum(object):
 
     """
 
+    ACCEPTED = 'Accepted'
+
     RUNNING = 'Running'
 
     CANCELED = 'Canceled'
