@@ -16,6 +16,9 @@ import cohesity_management_sdk.models_v2.smb_permission
 import cohesity_management_sdk.models_v2.acl_config_1
 import cohesity_management_sdk.models_v2.owner_info_2
 import cohesity_management_sdk.models_v2.view_share_permissions
+import cohesity_management_sdk.models_v2.view_pinning_config
+import cohesity_management_sdk.models_v2.self_service_snapshot_config
+
 
 class UpdateViewParam(object):
 
@@ -24,6 +27,8 @@ class UpdateViewParam(object):
     Specifies the settings that define a View.
 
     Attributes:
+        name (string): Specifies the name of the View.
+        category (Category1Enum): Specifies the category of the View.
         protocol_access (list of ProtocolOption): Specifies the supported
             Protocols for the View.
         qos (QoS): Specifies the Quality of Service (QoS) Policy for the
@@ -62,9 +67,11 @@ class UpdateViewParam(object):
             limit is increased or data is removed, there may be a delay before
             the Cohesity Cluster allows more data to be written to the
             resource, as the Cluster calculates the usage across Nodes.
-        file_lock_config (FileLevelDataLockConfigurations): Specifies a config
-            to lock files in a view - to protect from malicious or an
-            accidental attempt to delete or modify the files in this view.
+        file_lock_config (FileLockConfig): Optional config that enables file
+            locking for this view. It cannot be disabled during the edit of a
+            view, if it has been enabled during the creation of the view.
+            Also, it cannot be enabled if it was disabled during the creation
+            of the view.
         file_extension_filter (FileExtensionFilter): TODO: type description
             here.
         antivirus_scan_config (AntivirusScanConfig): Specifies the antivirus
@@ -91,6 +98,13 @@ class UpdateViewParam(object):
         view_lock_enabled (bool): Specifies whether view lock is enabled. If
             enabled the view cannot be modified or deleted until unlock. By
             default it is disabled.
+        is_read_only (bool): Specifies if the view is a read only view. User
+            will no longer be able to write to this view if this is set to
+            true.
+        view_pinning_config (ViewPinningConfig): Specifies the pinning config
+            of this view.
+        self_service_snapshot_config (SelfServiceSnapshotConfig): Specifies
+            self service config of this view.
         is_externally_triggered_backup_target (bool): Specifies whether the
             view is for externally triggered backup target. If so, Magneto
             will ignore the backup schedule for the view protection job of
@@ -129,15 +143,25 @@ class UpdateViewParam(object):
             information about SMB permissions.
         share_permissions (list of SMBPermission): Specifies a list of share
             level permissions.
+        s3_access_path (string): Specifies the path to access this View as an
+            S3 share.
         acl_config (AclConfig1): Specifies the ACL config of the View as an S3
             bucket.
         owner_info (OwnerInfo2): Specifies the owner info of the View as an S3
             bucket.
+        versioning (VersioningEnum): Specifies the versioning state of S3
+            bucket. Buckets can be in one of three states: UnVersioned
+            (default), VersioningEnabled, or VersioningSuspended. Once
+            versioning is enabled for a bucket, it can never return to an
+            UnVersioned state. However, versioning on the bucket can be
+            suspended.
 
     """
 
     # Create a mapping from Model property names to API property names
     _names = {
+        "name":'name',
+        "category":'category',
         "protocol_access":'protocolAccess',
         "qos":'qos',
         "override_global_subnet_whitelist":'overrideGlobalSubnetWhitelist',
@@ -161,6 +185,9 @@ class UpdateViewParam(object):
         "swift_project_name":'swiftProjectName',
         "access_sids":'accessSids',
         "view_lock_enabled":'viewLockEnabled',
+        "is_read_only":'isReadOnly',
+        "view_pinning_config":'viewPinningConfig',
+        "self_service_snapshot_config":'selfServiceSnapshotConfig',
         "is_externally_triggered_backup_target":'isExternallyTriggeredBackupTarget',
         "enable_nfs_view_discovery":'enableNfsViewDiscovery',
         "nfs_all_squash":'nfsAllSquash',
@@ -174,11 +201,15 @@ class UpdateViewParam(object):
         "enable_smb_oplock":'enableSmbOplock',
         "smb_permissions_info":'smbPermissionsInfo',
         "share_permissions":'sharePermissions',
+        "s3_access_path":'s3AccessPath',
         "acl_config":'aclConfig',
-        "owner_info":'ownerInfo'
+        "owner_info":'ownerInfo',
+        "versioning":'versioning'
     }
 
     def __init__(self,
+                 name=None,
+                 category=None,
                  protocol_access=None,
                  qos=None,
                  override_global_subnet_whitelist=None,
@@ -202,6 +233,9 @@ class UpdateViewParam(object):
                  swift_project_name=None,
                  access_sids=None,
                  view_lock_enabled=None,
+                 is_read_only=None,
+                 view_pinning_config=None,
+                 self_service_snapshot_config=None,
                  is_externally_triggered_backup_target=None,
                  enable_nfs_view_discovery=None,
                  nfs_all_squash=None,
@@ -215,12 +249,16 @@ class UpdateViewParam(object):
                  enable_smb_oplock=None,
                  smb_permissions_info=None,
                  share_permissions=None,
+                 s3_access_path=None,
                  acl_config=None,
-                 owner_info=None):
+                 owner_info=None,
+                 versioning=None):
         """Constructor for the UpdateViewParam class"""
 
         # Initialize members of the class
+        self.name = name
         self.protocol_access = protocol_access
+        self.category = category
         self.qos = qos
         self.override_global_subnet_whitelist = override_global_subnet_whitelist
         self.subnet_whitelist = subnet_whitelist
@@ -243,6 +281,9 @@ class UpdateViewParam(object):
         self.swift_project_name = swift_project_name
         self.access_sids = access_sids
         self.view_lock_enabled = view_lock_enabled
+        self.is_read_only = is_read_only
+        self.view_pinning_config = view_pinning_config
+        self.self_service_snapshot_config = self_service_snapshot_config
         self.is_externally_triggered_backup_target = is_externally_triggered_backup_target
         self.enable_nfs_view_discovery = enable_nfs_view_discovery
         self.nfs_all_squash = nfs_all_squash
@@ -256,8 +297,10 @@ class UpdateViewParam(object):
         self.enable_smb_oplock = enable_smb_oplock
         self.smb_permissions_info = smb_permissions_info
         self.share_permissions = share_permissions
+        self.s3_access_path = s3_access_path
         self.acl_config = acl_config
         self.owner_info = owner_info
+        self.versioning = versioning
 
 
     @classmethod
@@ -278,6 +321,8 @@ class UpdateViewParam(object):
             return None
 
         # Extract variables from the dictionary
+        name = dictionary.get('name')
+        category = dictionary.get('category')
         protocol_access = None
         if dictionary.get('protocolAccess') != None:
             protocol_access = list()
@@ -309,6 +354,9 @@ class UpdateViewParam(object):
         swift_project_name = dictionary.get('swiftProjectName')
         access_sids = dictionary.get('accessSids')
         view_lock_enabled = dictionary.get('viewLockEnabled')
+        is_read_only = dictionary.get('isReadOnly')
+        view_pinning_config = cohesity_management_sdk.models_v2.view_pinning_config.ViewPinningConfig.from_dictionary(dictionary.get('viewPinningConfig')) if dictionary.get('viewPinningConfig') else None
+        self_service_snapshot_config = cohesity_management_sdk.models_v2.self_service_snapshot_config.SelfServiceSnapshotConfig.from_dictionary(dictionary.get('selfServiceSnapshotConfig')) if dictionary.get('selfServiceSnapshotConfig') else None
         is_externally_triggered_backup_target = dictionary.get('isExternallyTriggeredBackupTarget')
         enable_nfs_view_discovery = dictionary.get('enableNfsViewDiscovery')
         nfs_all_squash = cohesity_management_sdk.models_v2.nfs_squash_specifies_the_squash_config_for_client_subnet_whitelist.NfsSquashSpecifiesTheSquashConfigForClientSubnetWhitelist.from_dictionary(dictionary.get('nfsAllSquash')) if dictionary.get('nfsAllSquash') else None
@@ -322,11 +370,15 @@ class UpdateViewParam(object):
         enable_smb_oplock = dictionary.get('enableSmbOplock')
         smb_permissions_info = cohesity_management_sdk.models_v2.smb_permissions_information.SMBPermissionsInformation.from_dictionary(dictionary.get('smbPermissionsInfo')) if dictionary.get('smbPermissionsInfo') else None
         share_permissions = cohesity_management_sdk.models_v2.view_share_permissions.ViewSharePermissions.from_dictionary(dictionary.get('sharePermissions')) if dictionary.get('sharePermissions') else None
+        s3_access_path = dictionary.get('s3AccessPath')
         acl_config = cohesity_management_sdk.models_v2.acl_config_1.AclConfig1.from_dictionary(dictionary.get('aclConfig')) if dictionary.get('aclConfig') else None
         owner_info = cohesity_management_sdk.models_v2.owner_info_2.OwnerInfo2.from_dictionary(dictionary.get('ownerInfo')) if dictionary.get('ownerInfo') else None
+        versioning = dictionary.get('versioning')
 
         # Return an object of this model
-        return cls(protocol_access,
+        return cls(name,
+                   category,
+                   protocol_access,
                    qos,
                    override_global_subnet_whitelist,
                    subnet_whitelist,
@@ -349,6 +401,9 @@ class UpdateViewParam(object):
                    swift_project_name,
                    access_sids,
                    view_lock_enabled,
+                   is_read_only,
+                   view_pinning_config,
+                   self_service_snapshot_config,
                    is_externally_triggered_backup_target,
                    enable_nfs_view_discovery,
                    nfs_all_squash,
@@ -362,7 +417,9 @@ class UpdateViewParam(object):
                    enable_smb_oplock,
                    smb_permissions_info,
                    share_permissions,
+                   s3_access_path,
                    acl_config,
-                   owner_info)
+                   owner_info,
+                   versioning)
 
 
