@@ -17,8 +17,12 @@ import cohesity_management_sdk.models_v2.acl_config_1
 import cohesity_management_sdk.models_v2.owner_info_2
 import cohesity_management_sdk.models_v2.view_protection
 import cohesity_management_sdk.models_v2.view_alias_information
+import cohesity_management_sdk.models_v2.view_failover
 import cohesity_management_sdk.models_v2.view_stats
 import cohesity_management_sdk.models_v2.view_share_permissions
+import cohesity_management_sdk.models_v2.file_count
+import cohesity_management_sdk.models_v2.view_pinning_config
+import cohesity_management_sdk.models_v2.self_service_snapshot_config
 
 class View1(object):
 
@@ -97,6 +101,13 @@ class View1(object):
         view_lock_enabled (bool): Specifies whether view lock is enabled. If
             enabled the view cannot be modified or deleted until unlock. By
             default it is disabled.
+        is_read_only (bool): Specifies if the view is a read only view. User
+            will no longer be able to write to this view if this is set to
+            true.
+        view_pinning_config (ViewPinningConfig):  Specifies the pinning
+            config of this view.
+        self_service_snapshot_config (SelfServiceSnapshotConfig): Specifies
+            self service config of this view.
         is_externally_triggered_backup_target (bool): Specifies whether the
             view is for externally triggered backup target. If so, Magneto
             will ignore the backup schedule for the view protection job of
@@ -111,6 +122,14 @@ class View1(object):
         nfs_root_squash
             (NfsSquashSpecifiesTheSquashConfigForClientSubnetWhitelist): TODO:
             type description here.
+        enable_nfs_unix_authentication (bool): If set, it enables NFS UNIX
+            Authentication
+        enable_nfs_kerberos_authentication (bool): If set, it enables NFS
+            Kerberos Authentication
+        enable_nfs_kerberos_integrity (bool): If set, it enables NFS Kerberos
+            Integrity
+        enable_nfs_kerberos_privacy (bool): If set, it enables NFS Kerberos
+            Privacy
         enable_smb_view_discovery (bool): If set, it enables discovery of view
             for SMB.
         enable_smb_access_based_enumeration (bool): Specifies if access-based
@@ -162,8 +181,11 @@ class View1(object):
             (without the hostname information). This path is used to support
             NFS mounting of the paths specified in the nfsExportPathList on
             Windows systems.
-        nfs_mount_path (string): Specifies the path for mounting this View as
-            an NFS share.
+        nfs_mount_path (string):This field is currently deprecated. Please use
+            NFS MountPaths which would be an array of strings
+        nfs_mount_paths (list of string): Array of NFS Paths. Specifies the
+            path for mounting this  View as an NFS share. If Kerberos Provider
+            has multiple hostaliases, each host alias has\n its own path.
         smb_mount_paths (list of string): Array of SMB Paths. Specifies the
             possible paths that can be used to mount this View as a SMB share.
             If Active Directory has multiple account names; each machine
@@ -183,7 +205,12 @@ class View1(object):
             using the alias name.
         is_target_for_migrated_data (bool): Specifies if a view contains
             migrated data.
+        view_failover (ViewFailover): Specifies the information about the
+            failover of the view.
         stats (ViewStats): Provides statistics about the View.
+        file_count_by_size (list of FileCount): Specifies the file count by
+            size for the View.
+        owner_sid (string): Specifies the sid of the view owner.
         object_services_mapping_config (ObjectServicesMappingConfigEnum):
             Specifies the Object Services key mapping config of the view. This
             parameter can only be set during create and cannot be changed.
@@ -193,6 +220,12 @@ class View1(object):
             S3 share.
         swift_user_domain (string): Specifies the Keystone user domain.
         swift_username (string): Specifies the Keystone username.
+        versioning (VersioningEnum): Specifies the versioning state of S3
+            bucket. Buckets can be in one of three states: UnVersioned
+            (default), VersioningEnabled, or VersioningSuspended. Once
+            versioning is enabled for a bucket, it can never return to an
+            UnVersioned state. However, versioning on the bucket can be
+            suspended.
 
     """
 
@@ -221,11 +254,18 @@ class View1(object):
         "swift_project_name":'swiftProjectName',
         "access_sids":'accessSids',
         "view_lock_enabled":'viewLockEnabled',
+        "is_read_only":'isReadOnly',
+        "view_pinning_config":'viewPinningConfig',
+        "self_service_snapshot_config":'selfServiceSnapshotConfig',
         "is_externally_triggered_backup_target":'isExternallyTriggeredBackupTarget',
         "enable_nfs_view_discovery":'enableNfsViewDiscovery',
         "nfs_all_squash":'nfsAllSquash',
         "nfs_root_permissions":'nfsRootPermissions',
         "nfs_root_squash":'nfsRootSquash',
+        "enable_nfs_unix_authentication":'enableNfsUnixAuthentication',
+        "enable_nfs_kerberos_authentication":'enableNfsKerberosAuthentication',
+        "enable_nfs_kerberos_integrity":'enableNfsKerberosIntegrity',
+        "enable_nfs_kerberos_privacy":'enableNfsKerberosPrivacy',
         "enable_smb_view_discovery":'enableSmbViewDiscovery',
         "enable_smb_access_based_enumeration":'enableSmbAccessBasedEnumeration',
         "enable_smb_encryption":'enableSmbEncryption',
@@ -245,17 +285,22 @@ class View1(object):
         "create_time_msecs":'createTimeMsecs',
         "basic_mount_path":'basicMountPath',
         "nfs_mount_path":'nfsMountPath',
+        "nfs_mount_paths":'nfsMountPaths',
         "smb_mount_paths":'smbMountPaths',
         "case_insensitive_names_enabled":'caseInsensitiveNamesEnabled',
         "view_protection":'viewProtection',
         "data_lock_expiry_usecs":'dataLockExpiryUsecs',
         "aliases":'aliases',
         "is_target_for_migrated_data":'isTargetForMigratedData',
+        "view_failover":'viewFailover',
         "stats":'stats',
+        "file_count_by_size":'fileCountBySize',
+        "owner_sid":'ownerSid',
         "object_services_mapping_config":'objectServicesMappingConfig',
         "s_3_access_path":'s3AccessPath',
         "swift_user_domain":'swiftUserDomain',
-        "swift_username":'swiftUsername'
+        "swift_username":'swiftUsername',
+        "versioning":'versioning'
     }
 
     def __init__(self,
@@ -282,11 +327,18 @@ class View1(object):
                  swift_project_name=None,
                  access_sids=None,
                  view_lock_enabled=None,
+                 is_read_only=None,
+                 view_pinning_config=None,
+                 self_service_snapshot_config=None,
                  is_externally_triggered_backup_target=None,
                  enable_nfs_view_discovery=None,
                  nfs_all_squash=None,
                  nfs_root_permissions=None,
                  nfs_root_squash=None,
+                 enable_nfs_unix_authentication=None,
+                 enable_nfs_kerberos_authentication=None,
+                 enable_nfs_kerberos_integrity=None,
+                 enable_nfs_kerberos_privacy=None,
                  enable_smb_view_discovery=None,
                  enable_smb_access_based_enumeration=None,
                  enable_smb_encryption=None,
@@ -306,17 +358,22 @@ class View1(object):
                  create_time_msecs=None,
                  basic_mount_path=None,
                  nfs_mount_path=None,
+                 nfs_mount_paths=None,
                  smb_mount_paths=None,
                  case_insensitive_names_enabled=None,
                  view_protection=None,
                  data_lock_expiry_usecs=None,
                  aliases=None,
                  is_target_for_migrated_data=None,
+                 view_failover=None,
                  stats=None,
+                 file_count_by_size=None,
+                 owner_sid=None,
                  object_services_mapping_config=None,
                  s_3_access_path=None,
                  swift_user_domain=None,
-                 swift_username=None):
+                 swift_username=None,
+                 versioning=None):
         """Constructor for the View1 class"""
 
         # Initialize members of the class
@@ -343,11 +400,18 @@ class View1(object):
         self.swift_project_name = swift_project_name
         self.access_sids = access_sids
         self.view_lock_enabled = view_lock_enabled
+        self.is_read_only = is_read_only
+        self.view_pinning_config = view_pinning_config
+        self.self_service_snapshot_config = self_service_snapshot_config
         self.is_externally_triggered_backup_target = is_externally_triggered_backup_target
         self.enable_nfs_view_discovery = enable_nfs_view_discovery
         self.nfs_all_squash = nfs_all_squash
         self.nfs_root_permissions = nfs_root_permissions
         self.nfs_root_squash = nfs_root_squash
+        self.enable_nfs_unix_authentication = enable_nfs_unix_authentication
+        self.enable_nfs_kerberos_authentication = enable_nfs_kerberos_authentication
+        self.enable_nfs_kerberos_integrity = enable_nfs_kerberos_integrity
+        self.enable_nfs_kerberos_privacy = enable_nfs_kerberos_privacy
         self.enable_smb_view_discovery = enable_smb_view_discovery
         self.enable_smb_access_based_enumeration = enable_smb_access_based_enumeration
         self.enable_smb_encryption = enable_smb_encryption
@@ -367,17 +431,22 @@ class View1(object):
         self.create_time_msecs = create_time_msecs
         self.basic_mount_path = basic_mount_path
         self.nfs_mount_path = nfs_mount_path
+        self.nfs_mount_paths = nfs_mount_paths
         self.smb_mount_paths = smb_mount_paths
         self.case_insensitive_names_enabled = case_insensitive_names_enabled
         self.view_protection = view_protection
         self.data_lock_expiry_usecs = data_lock_expiry_usecs
         self.aliases = aliases
         self.is_target_for_migrated_data = is_target_for_migrated_data
+        self.view_failover = view_failover
         self.stats = stats
+        self.file_count_by_size = file_count_by_size
+        self.owner_sid = owner_sid
         self.object_services_mapping_config = object_services_mapping_config
         self.s_3_access_path = s_3_access_path
         self.swift_user_domain = swift_user_domain
         self.swift_username = swift_username
+        self.versioning = versioning
 
 
     @classmethod
@@ -429,11 +498,18 @@ class View1(object):
         swift_project_name = dictionary.get('swiftProjectName')
         access_sids = dictionary.get('accessSids')
         view_lock_enabled = dictionary.get('viewLockEnabled')
+        is_read_only = dictionary.get('isReadOnly')
+        view_pinning_config = cohesity_management_sdk.models_v2.view_pinning_config.ViewPinningConfig.from_dictionary(dictionary.get('viewPinningConfig')) if dictionary.get('viewPinningConfig') else None
+        self_service_snapshot_config = cohesity_management_sdk.models_v2.self_service_snapshot_config.SelfServiceSnapshotConfig.from_dictionary(dictionary.get('selfServiceSnapshotConfig')) if dictionary.get('selfServiceSnapshotConfig') else None
         is_externally_triggered_backup_target = dictionary.get('isExternallyTriggeredBackupTarget')
         enable_nfs_view_discovery = dictionary.get('enableNfsViewDiscovery')
         nfs_all_squash = cohesity_management_sdk.models_v2.nfs_squash_specifies_the_squash_config_for_client_subnet_whitelist.NfsSquashSpecifiesTheSquashConfigForClientSubnetWhitelist.from_dictionary(dictionary.get('nfsAllSquash')) if dictionary.get('nfsAllSquash') else None
         nfs_root_permissions = cohesity_management_sdk.models_v2.nfs_root_permissions.NfsRootPermissions.from_dictionary(dictionary.get('nfsRootPermissions')) if dictionary.get('nfsRootPermissions') else None
         nfs_root_squash = cohesity_management_sdk.models_v2.nfs_squash_specifies_the_squash_config_for_client_subnet_whitelist.NfsSquashSpecifiesTheSquashConfigForClientSubnetWhitelist.from_dictionary(dictionary.get('nfsRootSquash')) if dictionary.get('nfsRootSquash') else None
+        enable_nfs_unix_authentication = dictionary.get('enableNfsUnixAuthentication')
+        enable_nfs_kerberos_authentication = dictionary.get('enableNfsKerberosAuthentication')
+        enable_nfs_kerberos_integrity = dictionary.get('enableNfsKerberosIntegrity')
+        enable_nfs_kerberos_privacy = dictionary.get('enableNfsKerberosPrivacy')
         enable_smb_view_discovery = dictionary.get('enableSmbViewDiscovery')
         enable_smb_access_based_enumeration = dictionary.get('enableSmbAccessBasedEnumeration')
         enable_smb_encryption = dictionary.get('enableSmbEncryption')
@@ -453,6 +529,7 @@ class View1(object):
         create_time_msecs = dictionary.get('createTimeMsecs')
         basic_mount_path = dictionary.get('basicMountPath')
         nfs_mount_path = dictionary.get('nfsMountPath')
+        nfs_mount_paths = dictionary.get('nfsMountPaths')
         smb_mount_paths = dictionary.get('smbMountPaths')
         case_insensitive_names_enabled = dictionary.get('caseInsensitiveNamesEnabled')
         view_protection = cohesity_management_sdk.models_v2.view_protection.ViewProtection.from_dictionary(dictionary.get('viewProtection')) if dictionary.get('viewProtection') else None
@@ -463,11 +540,19 @@ class View1(object):
             for structure in dictionary.get('aliases'):
                 aliases.append(cohesity_management_sdk.models_v2.view_alias_information.ViewAliasInformation.from_dictionary(structure))
         is_target_for_migrated_data = dictionary.get('isTargetForMigratedData')
+        view_failover = cohesity_management_sdk.models_v2.view_failover.ViewFailover.from_dictionary(dictionary.get('viewFailover')) if dictionary.get('viewFailover') else None
         stats = cohesity_management_sdk.models_v2.view_stats.ViewStats.from_dictionary(dictionary.get('stats')) if dictionary.get('stats') else None
+        file_count_by_size = None
+        if dictionary.get('fileCountBySize') != None:
+            file_count_by_size = list()
+            for structure in dictionary.get('fileCountBySize'):
+                file_count_by_size.append(cohesity_management_sdk.models_v2.file_count.FileCount.from_dictionary(structure))
+        owner_sid = dictionary.get('ownerSid')
         object_services_mapping_config = dictionary.get('objectServicesMappingConfig')
         s_3_access_path = dictionary.get('s3AccessPath')
         swift_user_domain = dictionary.get('swiftUserDomain')
         swift_username = dictionary.get('swiftUsername')
+        versioning = dictionary.get('versioning')
 
         # Return an object of this model
         return cls(protocol_access,
@@ -493,11 +578,18 @@ class View1(object):
                    swift_project_name,
                    access_sids,
                    view_lock_enabled,
+                   is_read_only,
+                   view_pinning_config,
+                   self_service_snapshot_config,
                    is_externally_triggered_backup_target,
                    enable_nfs_view_discovery,
                    nfs_all_squash,
                    nfs_root_permissions,
                    nfs_root_squash,
+                   enable_nfs_unix_authentication,
+                   enable_nfs_kerberos_authentication,
+                   enable_nfs_kerberos_integrity,
+                   enable_nfs_kerberos_privacy,
                    enable_smb_view_discovery,
                    enable_smb_access_based_enumeration,
                    enable_smb_encryption,
@@ -517,16 +609,21 @@ class View1(object):
                    create_time_msecs,
                    basic_mount_path,
                    nfs_mount_path,
+                   nfs_mount_paths,
                    smb_mount_paths,
                    case_insensitive_names_enabled,
                    view_protection,
                    data_lock_expiry_usecs,
                    aliases,
                    is_target_for_migrated_data,
+                   view_failover,
                    stats,
+                   file_count_by_size,
+                   owner_sid,
                    object_services_mapping_config,
                    s_3_access_path,
                    swift_user_domain,
-                   swift_username)
+                   swift_username,
+                   versioning)
 
 
